@@ -41,6 +41,9 @@ typedef struct {
 } TSK_JNI_FILEHANDLE;
 #define TSK_JNI_FILEHANDLE_TAG 0x10101214
 
+//stack-allocated buffer size for read method
+#define FIXED_BUF_SIZE (16 * 1024)
+
 /**
 * Sets flag to throw an TskCoreException back up to the Java code with a specific message.
 * Note: exception is thrown to Java code after the native function returns
@@ -447,19 +450,32 @@ JNIEXPORT jlong JNICALL
         return 0;
     }
 
-    char envstr[32];
-    snprintf(envstr, 32, "TZ=%s", env->GetStringUTFChars(timezone,
-            &isCopy));
-    if (0 != putenv(envstr)) {
-        stringstream ss;
-        ss << "Error setting timezone environment, using: ";
-        ss << envstr;
-        setThrowTskCoreError(env, ss.str().c_str());
-        return 0;
-    }
 
-    /* we should be checking this somehow */
-    TZSET();
+    if (env->GetStringUTFLength(timezone) > 0) {
+        const char *tzstr = env->GetStringUTFChars(timezone, &isCopy);
+
+        if (strlen(tzstr) > 64) {
+            stringstream ss;
+            ss << "Timezone is too long";
+            setThrowTskCoreError(env, ss.str().c_str());
+            return 0;
+        }
+
+        char envstr[70];
+        snprintf(envstr, 70, "TZ=%s", tzstr);
+        env->ReleaseStringUTFChars(timezone, tzstr);
+
+        if (0 != putenv(envstr)) {
+            stringstream ss;
+            ss << "Error setting timezone environment, using: ";
+            ss << envstr;
+            setThrowTskCoreError(env, ss.str().c_str());
+            return 0;
+        }
+
+        /* we should be checking this somehow */
+        TZSET();
+    }
 
     TskAutoDb *tskAuto = tskCase->initAddImage();
     if (tskAuto == NULL) {
@@ -524,11 +540,13 @@ JNIEXPORT void JNICALL
         }
     }
     
-    const char * tzchar = env->
+    if (env->GetStringLength(timezone) > 0) {
+        const char * tzchar = env->
             GetStringUTFChars(timezone, &isCopy);
 
-
-    tskAuto->setTz(string(tzchar));
+        tskAuto->setTz(string(tzchar));
+        env->ReleaseStringUTFChars(timezone, tzchar);
+    }
 
     // process the image (parts)
     uint8_t ret = 0;
@@ -561,8 +579,6 @@ JNIEXPORT void JNICALL
     }
     free(imagepaths8);
 
-    env->ReleaseStringUTFChars(timezone, tzchar);
-
     // @@@ SHOULD WE CLOSE HERE before we commit / revert etc.
     tskAuto->closeImage();
 
@@ -850,7 +866,7 @@ copyBufToByteArray(JNIEnv * env, const char *buf, ssize_t len)
  * @param len Length of bytes in buf
  * @returns number of bytes copied or -1 on error
  */
-static ssize_t
+inline static ssize_t
 copyBufToByteArray(JNIEnv * env, jbyteArray jbuf, const char *buf, ssize_t len)
 {
     env->SetByteArrayRegion(jbuf, 0, len, (jbyte*)buf);
@@ -870,15 +886,25 @@ JNIEXPORT jint JNICALL
 Java_org_sleuthkit_datamodel_SleuthkitJNI_readImgNat(JNIEnv * env,
     jclass obj, jlong a_img_info, jbyteArray jbuf, jlong offset, jlong len)
 {
-    char *buf = (char *) tsk_malloc((size_t) len);
-    if (buf == NULL) {
-        setThrowTskCoreError(env, tsk_error_get());
-        return -1;
+    //use fixed size stack-allocated buffer if possible
+    char fixed_buf [FIXED_BUF_SIZE];
+
+    char * buf = fixed_buf;
+    bool dynBuf = false;
+    if (len > FIXED_BUF_SIZE) {
+        dynBuf = true;
+        buf = (char *) tsk_malloc((size_t) len);
+        if (buf == NULL) {
+            setThrowTskCoreError(env);
+            return -1;
+        }
     }
 
     TSK_IMG_INFO *img_info = castImgInfo(env, a_img_info);
     if (img_info == 0) {
-        free(buf);
+        if (dynBuf) {
+            free(buf);
+        }
         //exception already set
         return -1;
     }
@@ -886,7 +912,9 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_readImgNat(JNIEnv * env,
     ssize_t bytesread =
         tsk_img_read(img_info, (TSK_OFF_T) offset, buf, (size_t) len);
     if (bytesread == -1) {
-        free(buf);
+        if (dynBuf) {
+            free(buf);
+        }
         setThrowTskCoreError(env, tsk_error_get());
         return -1;
     }
@@ -899,7 +927,9 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_readImgNat(JNIEnv * env,
         copybytes = jbuflen;
 
     ssize_t copiedbytes = copyBufToByteArray(env, jbuf, buf, copybytes);
-    free(buf);
+    if (dynBuf) {
+        free(buf);
+    }
 	if (copiedbytes == -1) {
         setThrowTskCoreError(env, tsk_error_get());
     }
@@ -920,15 +950,26 @@ JNIEXPORT jint JNICALL
 Java_org_sleuthkit_datamodel_SleuthkitJNI_readVsNat(JNIEnv * env,
     jclass obj, jlong a_vs_info, jbyteArray jbuf, jlong offset, jlong len)
 {
-    char *buf = (char *) tsk_malloc((size_t) len);
-    if (buf == NULL) {
-        setThrowTskCoreError(env);
-        return -1;
+    //use fixed size stack-allocated buffer if possible
+    char fixed_buf [FIXED_BUF_SIZE];
+
+    char * buf = fixed_buf;
+    bool dynBuf = false;
+    if (len > FIXED_BUF_SIZE) {
+        dynBuf = true;
+        buf = (char *) tsk_malloc((size_t) len);
+        if (buf == NULL) {
+            setThrowTskCoreError(env);
+            return -1;
+        }
     }
+
     TSK_VS_INFO *vs_info = castVsInfo(env, a_vs_info);
     if (vs_info == 0) {
         //exception already set
-        free(buf);
+        if (dynBuf) {
+            free(buf);
+        }
         return -1;
     }
 
@@ -936,6 +977,10 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_readVsNat(JNIEnv * env,
         (size_t) len);
     if (bytesread == -1) {
         setThrowTskCoreError(env, tsk_error_get());
+        if (dynBuf) {
+            free(buf);
+        }
+        return -1;
     }
 
     // package it up for return
@@ -946,7 +991,9 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_readVsNat(JNIEnv * env,
         copybytes = jbuflen;
 
     ssize_t copiedbytes = copyBufToByteArray(env, jbuf, buf, copybytes);
-    free(buf);
+    if (dynBuf) {
+        free(buf);
+    }
     if (copiedbytes == -1) {
         setThrowTskCoreError(env, tsk_error_get());
     }
@@ -968,15 +1015,25 @@ JNIEXPORT jint JNICALL
 Java_org_sleuthkit_datamodel_SleuthkitJNI_readVolNat(JNIEnv * env,
     jclass obj, jlong a_vol_info, jbyteArray jbuf, jlong offset, jlong len)
 {
-    char *buf = (char *) tsk_malloc((size_t) len);
-    if (buf == NULL) {
-        setThrowTskCoreError(env);
-        return -1;
+    //use fixed size stack-allocated buffer if possible
+    char fixed_buf [FIXED_BUF_SIZE];
+
+    char * buf = fixed_buf;
+    bool dynBuf = false;
+    if (len > FIXED_BUF_SIZE) {
+        dynBuf = true;
+        buf = (char *) tsk_malloc((size_t) len);
+        if (buf == NULL) {
+            setThrowTskCoreError(env);
+            return -1;
+        }
     }
 
     TSK_VS_PART_INFO *vol_part_info = castVsPartInfo(env, a_vol_info);
     if (vol_part_info == 0) {
-        free(buf);
+        if (dynBuf) {
+            free(buf);
+        }
         //exception already set
         return -1;
     }
@@ -985,7 +1042,9 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_readVolNat(JNIEnv * env,
         (size_t) len);
     if (bytesread == -1) {
         setThrowTskCoreError(env, tsk_error_get());
-        free(buf);
+        if (dynBuf) {
+            free(buf);
+        }
         return -1;
     }
 
@@ -997,7 +1056,9 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_readVolNat(JNIEnv * env,
         copybytes = jbuflen;
 
     ssize_t copiedbytes = copyBufToByteArray(env, jbuf, buf, copybytes);
-    free(buf);
+    if (dynBuf) {
+        free(buf);
+    }
     if (copiedbytes == -1) {
         setThrowTskCoreError(env, tsk_error_get());
     }
@@ -1018,14 +1079,25 @@ JNIEXPORT jint JNICALL
 Java_org_sleuthkit_datamodel_SleuthkitJNI_readFsNat(JNIEnv * env,
     jclass obj, jlong a_fs_info, jbyteArray jbuf, jlong offset, jlong len)
 {
-    char *buf = (char *) tsk_malloc((size_t) len);
-    if (buf == NULL) {
-        setThrowTskCoreError(env);
-        return -1;
+    //use fixed size stack-allocated buffer if possible
+    char fixed_buf [FIXED_BUF_SIZE];
+
+    char * buf = fixed_buf;
+    bool dynBuf = false;
+    if (len > FIXED_BUF_SIZE) {
+        dynBuf = true;
+        buf = (char *) tsk_malloc((size_t) len);
+        if (buf == NULL) {
+            setThrowTskCoreError(env);
+            return -1;
+        }
     }
+
     TSK_FS_INFO *fs_info = castFsInfo(env, a_fs_info);
     if (fs_info == 0) {
-        free(buf);
+        if (dynBuf) {
+            free(buf);
+        }
         //exception already set
         return -1;
     }
@@ -1033,7 +1105,9 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_readFsNat(JNIEnv * env,
     ssize_t bytesread =
         tsk_fs_read(fs_info, (TSK_OFF_T) offset, buf, (size_t) len);
     if (bytesread == -1) {
-        free(buf);
+        if (dynBuf) {
+            free(buf);
+        }
         setThrowTskCoreError(env, tsk_error_get());
         return -1;
     }
@@ -1046,7 +1120,9 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_readFsNat(JNIEnv * env,
         copybytes = jbuflen;
 
     ssize_t copiedbytes = copyBufToByteArray(env, jbuf, buf, copybytes);
-    free(buf);
+    if (dynBuf) {
+        free(buf);
+    }
     if (copiedbytes == -1) {
         setThrowTskCoreError(env, tsk_error_get());
     }
@@ -1069,15 +1145,25 @@ JNIEXPORT jint JNICALL
 Java_org_sleuthkit_datamodel_SleuthkitJNI_readFileNat(JNIEnv * env,
     jclass obj, jlong a_file_handle, jbyteArray jbuf, jlong offset, jlong len)
 {
-    char *buf = (char *) tsk_malloc((size_t) len);
-    if (buf == NULL) {
-        setThrowTskCoreError(env);
-        return -1;
+	//use fixed size stack-allocated buffer if possible
+    char fixed_buf [FIXED_BUF_SIZE];
+
+    char * buf = fixed_buf;
+    bool dynBuf = false;
+    if (len > FIXED_BUF_SIZE) {
+        dynBuf = true;
+        buf = (char *) tsk_malloc((size_t) len);
+        if (buf == NULL) {
+            setThrowTskCoreError(env);
+            return -1;
+        }
     }
 
     const TSK_JNI_FILEHANDLE *file_handle = castFsFile(env, a_file_handle);
     if (file_handle == 0) {
-        free(buf);
+        if (dynBuf) {
+            free(buf);
+        }
         //exception already set
         return -1;
     }
@@ -1088,7 +1174,9 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_readFileNat(JNIEnv * env,
     ssize_t bytesread = tsk_fs_attr_read(tsk_fs_attr,  (TSK_OFF_T) offset, buf, (size_t) len,
         TSK_FS_FILE_READ_FLAG_NONE);
     if (bytesread == -1) {
-        free(buf);
+        if (dynBuf) {
+            free(buf);
+        }
         setThrowTskCoreError(env, tsk_error_get());
         return -1;
     }
@@ -1101,7 +1189,9 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_readFileNat(JNIEnv * env,
 		copybytes = jbuflen;
 
     ssize_t copiedbytes = copyBufToByteArray(env, jbuf, buf, copybytes);
-    free(buf);
+    if (dynBuf) {
+        free(buf);
+    }
     if (copiedbytes == -1) {
         setThrowTskCoreError(env, tsk_error_get());
     }
@@ -1199,6 +1289,21 @@ Java_org_sleuthkit_datamodel_SleuthkitJNI_getVersionNat(JNIEnv * env,
     return jversion;
 }
 
+/*
+ * Get the current directory being analyzed during AddImage
+ * @return the path of the current directory
+ *
+ */
+JNIEXPORT jstring JNICALL
+    Java_org_sleuthkit_datamodel_SleuthkitJNI_getCurDirNat
+    (JNIEnv * env,jclass obj, jlong dbHandle)
+{
+    TskAutoDb *tskAuto = ((TskAutoDb *) dbHandle);
+    const std::string & curDir = tskAuto->getCurDir();
+    jstring jdir = (*env).NewStringUTF(curDir.c_str());
+    return jdir;
+}
+
 /*
  * Enable verbose logging and redirect stderr to the given log file.
  * @param env pointer to java environment this was called from
