@@ -18,9 +18,13 @@
  */
 package org.sleuthkit.datamodel;
 
-import java.util.ArrayList;
 import java.util.List;
+import org.sleuthkit.datamodel.TskData.FileKnown;
 import org.sleuthkit.datamodel.TskData.TSK_DB_FILES_TYPE_ENUM;
+import org.sleuthkit.datamodel.TskData.TSK_FS_ATTR_TYPE_ENUM;
+import org.sleuthkit.datamodel.TskData.TSK_FS_META_TYPE_ENUM;
+import org.sleuthkit.datamodel.TskData.TSK_FS_NAME_FLAG_ENUM;
+import org.sleuthkit.datamodel.TskData.TSK_FS_NAME_TYPE_ENUM;
 
 /**
  * Representation of Directory object, stored in tsk_files table. Directory can
@@ -31,12 +35,12 @@ public class Directory extends FsContent {
 
 	//constructor used for getdir from tskDb
 	protected Directory(SleuthkitCase db, long obj_id, long fs_obj_id, long meta_addr,
-			short attr_type, short attr_id, String name, short dir_type,
-			short meta_type, short dir_flags, short meta_flags, long size,
+			TSK_FS_ATTR_TYPE_ENUM attr_type, short attr_id, String name, TSK_FS_NAME_TYPE_ENUM dirType,
+			TSK_FS_META_TYPE_ENUM metaType, TSK_FS_NAME_FLAG_ENUM dirFlag, short meta_flags, long size,
 			long ctime, long crtime, long atime, long mtime, short mode,
-			int uid, int gid, byte known, String parent_path, String md5Hash) {
+			int uid, int gid, FileKnown known, String parent_path, String md5Hash) {
 		super(db, obj_id, name, fs_obj_id, meta_addr,
-				attr_type, attr_id, meta_type, dir_type, dir_flags,
+				attr_type, attr_id, metaType, dirType, dirFlag,
 				meta_flags, size, ctime, crtime, atime, mtime, uid, gid, mode, known,
 				parent_path, md5Hash);
 	}
