@@ -18,7 +18,7 @@
  */
 package org.sleuthkit.datamodel;
 
-import java.util.*;
+import java.util.List;
 
 /**
  * Represents a file system object stored in tsk_fs_info table
@@ -29,11 +29,11 @@ import java.util.*;
  */
 public class FileSystem extends AbstractContent {
 
-	private long img_offset, block_size, block_count, root_inum,
-			first_inum, last_inum;
-	private TskData.TSK_FS_TYPE_ENUM fs_type;
+	private long imgOffset, blockSize, blockCount, rootInum,
+			firstInum, lastInum;
+	private TskData.TSK_FS_TYPE_ENUM fsType;
 	private Content parent;
-	private long filesystemHandle = 0;
+	private volatile long filesystemHandle = 0;
 
 	/**
 	 * Constructor most inputs are from the database
@@ -52,45 +52,24 @@ public class FileSystem extends AbstractContent {
 			TskData.TSK_FS_TYPE_ENUM fs_type, long block_size, long block_count, long root_inum,
 			long first_inum, long last_inum) {
 		super(db, obj_id, name);
-		this.img_offset = img_offset;
-		this.fs_type = fs_type;
-		this.block_size = block_size;
-		this.block_count = block_count;
-		this.root_inum = root_inum;
-		this.first_inum = first_inum;
-		this.last_inum = last_inum;
+		this.imgOffset = img_offset;
+		this.fsType = fs_type;
+		this.blockSize = block_size;
+		this.blockCount = block_count;
+		this.rootInum = root_inum;
+		this.firstInum = first_inum;
+		this.lastInum = last_inum;
 	}
 
-	/**
-	 * Set the parent content object, will be called by the parent 
-	 * when populating the object from database.
-	 * 
-	 * @param p parent volume or image.
-	 * Should only be called by methods which ensure p is a volume or image
-	 */
-	protected void setParent(Content p) {
-		parent = p;
-	}
-
-
 	@Override
 	public synchronized int read(byte[] buf, long offset, long len) throws TskCoreException {
 		return SleuthkitJNI.readFs(getFileSystemHandle(), buf, offset, len);
 	}
 
-	/**
-	 * Get the parent volume or image Content object
-	 * @return parent content object (volume or image)
-	 */
-	public Content getParent() {
-		return parent;
-	}
-
-
 	@Override
 	public long getSize() {
 		// size of the file system
-		return block_size * block_count;
+		return blockSize * blockCount;
 	}
 
 	/**
@@ -101,18 +80,32 @@ public class FileSystem extends AbstractContent {
 	 */
 	synchronized long getFileSystemHandle() throws TskCoreException {
 		if (filesystemHandle == 0) {
-			filesystemHandle = SleuthkitJNI.openFs(getImage().getImageHandle(), img_offset);
+			filesystemHandle = SleuthkitJNI.openFs(getImage().getImageHandle(), imgOffset);
 		}
 		return this.filesystemHandle;
 	}
+	
+	public Directory getRootDirectory() throws TskCoreException {
+		
+		List<Content> children = getChildren();
+		if (children.size() != 1) {
+			throw new TskCoreException("FileSystem must have only one child.");
+		}
+		
+		if (!(children.get(0) instanceof Directory)) {
+			throw new TskCoreException("Child of FileSystem must be a Directory.");
+		}
+
+		return (Directory)children.get(0);
+	}
 
 	/**
 	 * Get the byte offset of this file system in the image
 	 * 
 	 * @return offset
 	 */
-	public long getImg_offset() {
-		return img_offset;
+	public long getImageOffset() {
+		return imgOffset;
 	}
 
 	/**
@@ -120,8 +113,8 @@ public class FileSystem extends AbstractContent {
 	 * 
 	 * @return enum value of fs type
 	 */
-	public TskData.TSK_FS_TYPE_ENUM getFs_type() {
-		return fs_type;
+	public TskData.TSK_FS_TYPE_ENUM getFsType() {
+		return fsType;
 	}
 
 	/**
@@ -130,7 +123,7 @@ public class FileSystem extends AbstractContent {
 	 * @return block size
 	 */
 	public long getBlock_size() {
-		return block_size;
+		return blockSize;
 	}
 
 	/**
@@ -139,7 +132,7 @@ public class FileSystem extends AbstractContent {
 	 * @return block count
 	 */
 	public long getBlock_count() {
-		return block_count;
+		return blockCount;
 	}
 
 	/**
@@ -148,7 +141,7 @@ public class FileSystem extends AbstractContent {
 	 * @return Root metadata address of the file system
 	 */
 	public long getRoot_inum() {
-		return root_inum;
+		return rootInum;
 	}
 
 	/**
@@ -157,38 +150,40 @@ public class FileSystem extends AbstractContent {
 	 * @return first inum
 	 */
 	public long getFirst_inum() {
-		return first_inum;
+		return firstInum;
 	}
 
 	/**
 	 * Get the last inum
 	 * @return last inum
 	 */
-	public long getLast_inum() {
-		return last_inum;
+	public long getLastInum() {
+		return lastInum;
 	}
 
-
 	@Override
-	public void finalize() {
-		if (filesystemHandle != 0) {
-			SleuthkitJNI.closeFs(filesystemHandle);
+	public void finalize() throws Throwable {
+		try {
+			if (filesystemHandle != 0) {
+				SleuthkitJNI.closeFs(filesystemHandle);
+				filesystemHandle = 0;
+			}
+		}
+		finally {
+			super.finalize();
 		}
 	}
 
-
 	@Override
 	public <T> T accept(SleuthkitItemVisitor<T> v) {
 		return v.visit(this);
 	}
 
-
 	@Override
 	public <T> T accept(ContentVisitor<T> v) {
 		return v.visit(this);
 	}
 
-
 	@Override
 	public List<Content> getChildren() throws TskCoreException {
 		return getSleuthkitCase().getFileSystemChildren(this);
@@ -199,7 +194,6 @@ public class FileSystem extends AbstractContent {
 		return getSleuthkitCase().getFileSystemChildrenIds(this);
 	}
 
-
 	@Override
 	public Image getImage() throws TskCoreException {
 		return getParent().getImage();
