@@ -20,45 +20,63 @@ package org.sleuthkit.datamodel;
 
 import java.util.Collections;
 import java.util.List;
-import java.util.StringTokenizer;
+import java.util.Set;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import org.sleuthkit.datamodel.TskData.FileKnown;
+import org.sleuthkit.datamodel.TskData.TSK_FS_ATTR_TYPE_ENUM;
+import org.sleuthkit.datamodel.TskData.TSK_FS_META_FLAG_ENUM;
+import org.sleuthkit.datamodel.TskData.TSK_FS_META_MODE_ENUM;
+import org.sleuthkit.datamodel.TskData.TSK_FS_META_TYPE_ENUM;
+import org.sleuthkit.datamodel.TskData.TSK_FS_NAME_FLAG_ENUM;
+import org.sleuthkit.datamodel.TskData.TSK_FS_NAME_TYPE_ENUM;
 
 /**
  * Generalized class that stores metadata that are common to both File and
  * Directory objects stored in tsk_files table Caches internal tsk file handle
  * and reuses it for reads
+ *
+ * TODO move common getters to AbstractFile class
  */
 public abstract class FsContent extends AbstractFile {
+	
+	private static final Logger logger = Logger.getLogger(AbstractFile.class.getName());
 
 	///read only database tsk_files fields
-	protected final long fs_obj_id, meta_addr, size, ctime, crtime, atime, mtime;
+	protected final long fsObjId, metaAddr, size, ctime, crtime, atime, mtime;
 	protected final int uid, gid;
-	protected final short attr_type, attr_id, meta_type, dir_type, mode;
-	protected final short dir_flags, meta_flags;
-	
+	protected final short attrId;
+	protected final TSK_FS_ATTR_TYPE_ENUM attrType;
+	protected final TSK_FS_META_TYPE_ENUM metaType;
+	protected final Set<TSK_FS_META_FLAG_ENUM> metaFlags;
+	protected final Set<TSK_FS_META_MODE_ENUM> modes;
+	protected final TSK_FS_NAME_TYPE_ENUM dirType;
+	protected final TSK_FS_NAME_FLAG_ENUM dirFlag;
 	/*
 	 * path of parent directory
 	 */
-	protected final String parent_path;
+	protected final String parentPath;
+	
+	private String uniquePath;
+
 	///read-write database tsk_files fields
 	/**
 	 * known status in database
 	 */
-	protected byte known;
+	protected FileKnown known;
 	/*
 	 * md5 hash
 	 */
 	protected String md5Hash;
 	///other members
-
 	/**
 	 * parent file system
 	 */
-	protected FileSystem parentFileSystem;
+	private FileSystem parentFileSystem;
 	/**
 	 * file Handle
 	 */
-	protected long fileHandle = 0;
+	protected volatile long fileHandle = 0;
 
 	/**
 	 * Constructor to create FsContent object instance from database
@@ -84,21 +102,21 @@ public abstract class FsContent extends AbstractFile {
 	 * @param mode
 	 * @param known
 	 * @param parent_path
-	 * @param md5Hash
+	 * @param md5Hash String of MD5 hash of content or null if not known
 	 */
 	FsContent(SleuthkitCase db, long obj_id, String name, long fs_obj_id, long meta_addr,
-			short attr_type, short attr_id, short meta_type, short dir_type, short dir_flags,
-			short meta_flags, long size, long ctime, long crtime, long atime, long mtime, int uid, int gid, short mode, byte known,
+			TSK_FS_ATTR_TYPE_ENUM attrType, short attr_id, TSK_FS_META_TYPE_ENUM metaType, TSK_FS_NAME_TYPE_ENUM dirType, TSK_FS_NAME_FLAG_ENUM dirFlag,
+			short meta_flags, long size, long ctime, long crtime, long atime, long mtime, int uid, int gid, short modes, FileKnown known,
 			String parent_path, String md5Hash) {
 		super(db, obj_id, name, TskData.TSK_DB_FILES_TYPE_ENUM.FS);
-		this.fs_obj_id = fs_obj_id;
-		this.meta_addr = meta_addr;
-		this.attr_type = attr_type;
-		this.attr_id = attr_id;
-		this.meta_type = meta_type;
-		this.dir_type = dir_type;
-		this.dir_flags = dir_flags;
-		this.meta_flags = meta_flags;
+		this.fsObjId = fs_obj_id;
+		this.metaAddr = meta_addr;
+		this.attrType = attrType;
+		this.attrId = attr_id;
+		this.metaType = metaType;
+		this.dirType = dirType;
+		this.dirFlag = dirFlag;
+		this.metaFlags = TSK_FS_META_FLAG_ENUM.valuesOf(meta_flags);
 		this.size = size;
 		this.ctime = ctime;
 		this.crtime = crtime;
@@ -106,9 +124,9 @@ public abstract class FsContent extends AbstractFile {
 		this.mtime = mtime;
 		this.uid = uid;
 		this.gid = gid;
-		this.mode = mode;
+		this.modes = TSK_FS_META_MODE_ENUM.valuesOf(modes);
 		this.known = known;
-		this.parent_path = parent_path;
+		this.parentPath = parent_path;
 		this.md5Hash = md5Hash;
 	}
 
@@ -117,59 +135,69 @@ public abstract class FsContent extends AbstractFile {
 	 *
 	 * @param parent parent file system object
 	 */
-	protected void setFileSystem(FileSystem parent) {
+	void setFileSystem(FileSystem parent) {
 		parentFileSystem = parent;
 	}
 
 	/**
-	 * Sets md5 hash string
-	 * Note: database or other FsContent objects are not updated.
-	 * Currently only SleuthkiCase calls it to update the object while updating tsk_files entry
-	 * 
-	 * @param md5Hash 
+	 * Sets md5 hash string Note: database or other FsContent objects are not
+	 * updated. Currently only SleuthkiCase calls it to update the object while
+	 * updating tsk_files entry
+	 *
+	 * @param md5Hash
 	 */
 	void setMd5Hash(String md5Hash) {
 		this.md5Hash = md5Hash;
 	}
 
 	/**
-	 * Sets known status
-	 * Note: database or other FsContent objects are not updated.
-	 * Currently only SleuthkiCase calls it to update the object while updating tsk_files entry
-	 * 
-	 * @param known 
+	 * Sets known status Note: database or other FsContent objects are not
+	 * updated. Currently only SleuthkiCase calls it to update the object while
+	 * updating tsk_files entry
+	 *
+	 * @param known
 	 */
-	void setKnown(byte known) {
+	void setKnown(FileKnown known) {
 		this.known = known;
 	}
 
 	@Override
 	public int read(byte[] buf, long offset, long len) throws TskCoreException {
+		if (offset == 0 && size == 0) {
+			//special case for 0-size file
+			return 0;
+		}
 		synchronized (this) {
 			if (fileHandle == 0) {
-				fileHandle = 
-						SleuthkitJNI.openFile(parentFileSystem.getFileSystemHandle(), meta_addr, attr_type, attr_id);
+				fileHandle = SleuthkitJNI.openFile(getFileSystem().getFileSystemHandle(), metaAddr, attrType, attrId);
 			}
 		}
 		return SleuthkitJNI.readFile(fileHandle, buf, offset, len);
 	}
 
+	@Override
+	public boolean isRoot() {
+		try {
+			getFileSystem();
+		} catch (TskCoreException ex) {
+			logger.log(Level.SEVERE, "Exception while calling 'getFileSystem' on " + this, ex);
+			return false;
+		}
+		return parentFileSystem.getRoot_inum() == this.getMetaAddr();
+	}
+
 	/*
 	 * -------------------------------------------------------------------------
 	 * Getters to retrieve meta-data attributes values
 	 * -------------------------------------------------------------------------
 	 */
-	public boolean isRoot() {
-		return parentFileSystem.getRoot_inum() == this.getMeta_addr();
-	}
-
 	/**
 	 * Gets parent directory
 	 *
 	 * @return the parent Directory
 	 * @throws TskCoreException exception thrown if error occurred in tsk core
 	 */
-	public Directory getParentDirectory() throws TskCoreException {
+	public AbstractFile getParentDirectory() throws TskCoreException {
 		return getSleuthkitCase().getParentDirectory(this);
 	}
 
@@ -178,13 +206,16 @@ public abstract class FsContent extends AbstractFile {
 	 *
 	 * @return the file system object of the parent
 	 */
-	public FileSystem getFileSystem() {
+	public FileSystem getFileSystem() throws TskCoreException {
+		if (parentFileSystem == null) {
+			parentFileSystem = getSleuthkitCase().getFileSystemById(fsObjId, AbstractContent.UNKNOWN_ID);
+		}
 		return parentFileSystem;
 	}
-
+	
 	@Override
 	public Image getImage() throws TskCoreException {
-		return this.getFileSystem().getImage();
+		return getFileSystem().getImage();
 	}
 
 	/**
@@ -192,8 +223,8 @@ public abstract class FsContent extends AbstractFile {
 	 *
 	 * @return attribute type
 	 */
-	public short getAttr_type() {
-		return attr_type;
+	public TSK_FS_ATTR_TYPE_ENUM getAttrType() {
+		return attrType;
 	}
 
 	/**
@@ -201,8 +232,8 @@ public abstract class FsContent extends AbstractFile {
 	 *
 	 * @return attribute id
 	 */
-	public short getAttr_id() {
-		return attr_id;
+	public short getAttrId() {
+		return attrId;
 	}
 
 	/**
@@ -210,17 +241,12 @@ public abstract class FsContent extends AbstractFile {
 	 *
 	 * @return meta data type
 	 */
-	public short getMeta_type() {
-		return meta_type;
+	public TSK_FS_META_TYPE_ENUM getMetaType() {
+		return metaType;
 	}
 
-	/**
-	 * Get the meta data type as String
-	 *
-	 * @return meta data type as String
-	 */
 	public String getMetaTypeAsString() {
-		return FsContent.metaTypeToString(meta_type);
+		return metaType.toString();
 	}
 
 	/**
@@ -228,35 +254,28 @@ public abstract class FsContent extends AbstractFile {
 	 *
 	 * @return directory type id
 	 */
-	public short getDir_type() {
-		return dir_type;
+	public TSK_FS_NAME_TYPE_ENUM getDirType() {
+		return dirType;
 	}
 
-	/**
-	 * Get the directory type as String
-	 *
-	 * @return directory type as String
-	 */
 	public String getDirTypeAsString() {
-		return FsContent.dirTypeToString(dir_type);
+		return dirType.toString();
 	}
 
 	/**
-	 * Get the directory flags
-	 *
-	 * @return directory flags
+	 * @param flag the TSK_FS_NAME_FLAG_ENUM to check
+	 * @return true if the given flag is set in this FsContent object.
 	 */
-	public short getDir_flags() {
-		return dir_flags;
+	public boolean isDirNameFlagSet(TSK_FS_NAME_FLAG_ENUM flag) {
+		return dirFlag == flag;
 	}
 
 	/**
-	 * Get the directory flags as String
-	 *
-	 * @return directory flags as String
+	 * @return a string representation of the directory name flag (type
+	 * TSK_FS_NAME_FLAG_ENUM)
 	 */
-	public String getDirFlagsAsString() {
-		return FsContent.dirFlagToString(dir_flags);
+	public String getDirFlagAsString() {
+		return dirFlag.toString();
 	}
 
 	/**
@@ -264,26 +283,29 @@ public abstract class FsContent extends AbstractFile {
 	 *
 	 * @return Address of the meta data structure
 	 */
-	public long getMeta_addr() {
-		return meta_addr;
+	public long getMetaAddr() {
+		return metaAddr;
 	}
 
 	/**
-	 * Get the meta data flags
-	 *
-	 * @return meta data flags
-	 */
-	public short getMeta_flags() {
-		return meta_flags;
-	}
-
-	/**
-	 * Get the meta data flags as String
-	 *
-	 * @return meta data flags as String
+	 * @return a string representation of the meta flags
 	 */
 	public String getMetaFlagsAsString() {
-		return FsContent.metaFlagToString(meta_flags);
+		String str = "";
+		if (metaFlags.contains(TSK_FS_META_FLAG_ENUM.ALLOC)) {
+			str = TSK_FS_META_FLAG_ENUM.ALLOC.toString();
+		} else if (metaFlags.contains(TSK_FS_META_FLAG_ENUM.ALLOC)) {
+			str = TSK_FS_META_FLAG_ENUM.UNALLOC.toString();
+		}
+		return str;
+	}
+
+	/**
+	 * @param metaFlag the TSK_FS_META_FLAG_ENUM to check
+	 * @return true if the given meta flag is set in this FsContent object.
+	 */
+	public boolean isMetaFlagSet(TSK_FS_META_FLAG_ENUM metaFlag) {
+		return metaFlags.contains(metaFlag);
 	}
 
 	@Override
@@ -387,363 +409,14 @@ public abstract class FsContent extends AbstractFile {
 	}
 
 	/**
-	 * Get the mode
+	 * Get the file's mode as a user-displayable string
 	 *
-	 * @return mode
+	 * @return  formatted user-displayable string for mode
 	 */
-	public short getMode() {
-		return mode;
-	}
-
-	/**
-	 * Get the mode as String
-	 *
-	 * @return mode as String
-	 */
-	public String getModeAsString() {
-		return FsContent.modeToString(mode, meta_type);
-	}
-
-	/**
-	 * Get "known" file status - after running a HashDB ingest on it As marked
-	 * by a known file database, such as NSRL
-	 *
-	 * @return file known status enum value
-	 */
-	public FileKnown getKnown() {
-		return FileKnown.valueOf(this.known);
-	}
-
-	/**
-	 * Get the absolute parent path string of this FsContent
-	 *
-	 * @return the parent path string
-	 */
-	public String getParentPath() {
-		return this.parent_path;
-	}
-
-	@Override
-	public String getUniquePath() throws TskCoreException {
-		if (unique_path != null) {
-			return unique_path;
-		}
-
-		StringBuilder sb = new StringBuilder();
-		//prepend image and volume to file path
-		Image image = this.getImage();
-		StringTokenizer tok = new StringTokenizer(image.getName(), "/\\");
-		String imageName = null;
-		while (tok.hasMoreTokens()) {
-			imageName = tok.nextToken();
-		}
-		sb.append("/").append(imageName);
-		if (parentFileSystem != null) {
-			Content vol = parentFileSystem.getParent();
-			if (vol != null
-					&& !vol.equals(image)) {
-				sb.append("/");
-				sb.append(vol.getName());
-			}
-		}
-
-		sb.append(getParentPath());
-		sb.append(getName());
-
-		unique_path = sb.toString();
-		return unique_path;
-	}
-
-	/**
-	 * Get the md5 hash value as calculated, if present
-	 *
-	 * @return md5 hash string, if it is present
-	 */
-	public String getMd5Hash() {
-		return this.md5Hash;
-	}
-
-	@Override
-	public void finalize() {
-		if (fileHandle != 0) {
-			SleuthkitJNI.closeFile(fileHandle);
-		}
-	}
-
-	/*
-	 * -------------------------------------------------------------------------
-	 * Util methods to convert / map the data
-	 * -------------------------------------------------------------------------
-	 */
-	/**
-	 * Return the epoch into string in ISO 8601 dateTime format
-	 *
-	 * @param epoch time in seconds
-	 * @return formatted date time string as "yyyy-MM-dd HH:mm:ss"
-	 */
-	public static String epochToTime(long epoch) {
-		String time = "0000-00-00 00:00:00";
-		if (epoch != 0) {
-			time = new java.text.SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new java.util.Date(epoch * 1000));
-		}
-		return time;
-	}
-
-	/**
-	 * Convert from ISO 8601 formatted date time string to epoch time in seconds
-	 *
-	 * @param time formatted date time string as "yyyy-MM-dd HH:mm:ss"
-	 * @return epoch time in seconds
-	 */
-	public static long timeToEpoch(String time) {
-		long epoch = 0;
-		try {
-			epoch = new java.text.SimpleDateFormat("yyyy-MM-dd HH:mm:ss").parse(time).getTime() / 1000;
-		} catch (Exception e) {
-		}
-
-		return epoch;
-	}
-
-	/*
-	 * -------------------------------------------------------------------------
-	 * Methods for Directory type conversion / mapping ---
-	 * -------------------------------------------------------------------------
-	 */
-	/**
-	 * Get a string value of a directory type from dir type id as defined in
-	 * TSK_FS_NAME_TYPE_ENUM
-	 *
-	 * @param dirType to convert
-	 * @return dir type value string representation
-	 */
-	public static String dirTypeToValue(short dirType) {
-
+	public String getModesAsString() {
+		int mode = TSK_FS_META_MODE_ENUM.toInt(modes);
 		String result = "";
 
-		for (TskData.TSK_FS_NAME_TYPE_ENUM type : TskData.TSK_FS_NAME_TYPE_ENUM.values()) {
-			if (type.getDirType() == dirType) {
-				result = type.toString();
-			}
-		}
-		return result;
-	}
-
-	/**
-	 * Get a value type id from value type string
-	 *
-	 * @param dirType value string to convert
-	 * @return directory type id
-	 */
-	public static short valueToDirType(String dirType) {
-
-		short result = 0;
-
-		for (TskData.TSK_FS_NAME_TYPE_ENUM type : TskData.TSK_FS_NAME_TYPE_ENUM.values()) {
-			if (type.toString().equals(dirType)) {
-				result = type.getDirType();
-			}
-		}
-		return result;
-	}
-
-	/**
-	 * Get a dir type label string from dir type id
-	 *
-	 * @param dirType dir type id to convert
-	 * @return dir type label string
-	 */
-	public static String dirTypeToString(short dirType) {
-		return TskData.TSK_FS_NAME_TYPE_ENUM.fromType(dirType).getLabel();
-	}
-
-	// -------- Methods for Meta Type conversion / mapping --------
-	/**
-	 * Convert meta type id to string value
-	 *
-	 * @param metaType to convert
-	 * @return string value representation of meta type
-	 */
-	public static String metaTypeToValue(short metaType) {
-
-		String result = "";
-
-		for (TskData.TSK_FS_META_TYPE_ENUM type : TskData.TSK_FS_META_TYPE_ENUM.values()) {
-			if (type.getMetaType() == metaType) {
-				result = type.toString();
-			}
-		}
-		return result;
-	}
-
-	/**
-	 * Convert meta type string value to meta type id
-	 *
-	 * @param metaType to convert
-	 * @return meta type id
-	 */
-	public static short valueToMetaType(String metaType) {
-
-		short result = 0;
-
-		for (TskData.TSK_FS_META_TYPE_ENUM type : TskData.TSK_FS_META_TYPE_ENUM.values()) {
-			if (type.toString().equals(metaType)) {
-				result = type.getMetaType();
-			}
-		}
-		return result;
-	}
-
-	/**
-	 * Convert meta type id to string representation
-	 *
-	 * @param metaType to convert
-	 * @return string representation of the meta type
-	 */
-	public static String metaTypeToString(short metaType) {
-		return TskData.tsk_fs_meta_type_str[metaType];
-	}
-
-// ----- Methods for Directory Flags conversion / mapping -----
-	/**
-	 * Convert dir flags to string value
-	 *
-	 * @param dirFlag to convert
-	 * @return dir flags string representation
-	 */
-	public static String dirFlagToValue(short dirFlag) {
-
-		String result = "";
-
-		for (TskData.TSK_FS_NAME_FLAG_ENUM flag : TskData.TSK_FS_NAME_FLAG_ENUM.values()) {
-			if (flag.getDirFlag() == dirFlag) {
-				result = flag.toString();
-			}
-		}
-		return result;
-	}
-
-	/**
-	 * Convert string value to dir flag id
-	 *
-	 * @param dirFlag to convert
-	 * @return dir flag id
-	 */
-	public static short valueToDirFlag(String dirFlag) {
-
-		short result = 0;
-
-		for (TskData.TSK_FS_NAME_FLAG_ENUM flag : TskData.TSK_FS_NAME_FLAG_ENUM.values()) {
-			if (flag.toString().equals(dirFlag)) {
-				result = flag.getDirFlag();
-			}
-		}
-		return result;
-	}
-
-	/**
-	 * Convert dir flag to user displayable string
-	 *
-	 * @param dirFlag dir flags id to convert
-	 * @return formatted user-readable string representation of dir flag
-	 */
-	public static String dirFlagToString(short dirFlag) {
-
-		String result = "";
-
-		short allocFlag = TskData.TSK_FS_NAME_FLAG_ENUM.TSK_FS_NAME_FLAG_ALLOC.getDirFlag();
-		short unallocFlag = TskData.TSK_FS_NAME_FLAG_ENUM.TSK_FS_NAME_FLAG_UNALLOC.getDirFlag();
-
-		if ((dirFlag & allocFlag) == allocFlag) {
-			result = "Allocated";
-		}
-		if ((dirFlag & unallocFlag) == unallocFlag) {
-			result = "Unallocated";
-		}
-
-		return result;
-	}
-
-	// ----- Methods for Meta Flags conversion / mapping -----
-	/**
-	 * Convert meta flags to string value
-	 *
-	 * @param metaFlag to convert
-	 * @return string representation
-	 */
-	public static String metaFlagToValue(short metaFlag) {
-
-		String result = "";
-
-		for (TskData.TSK_FS_META_FLAG_ENUM flag : TskData.TSK_FS_META_FLAG_ENUM.values()) {
-			if (flag.getMetaFlag() == metaFlag) {
-				result = flag.toString();
-			}
-		}
-		return result;
-	}
-
-	/**
-	 * Convert string representation of meta flags to short
-	 *
-	 * @param metaFlag string to convert
-	 * @return short meta flag representation
-	 */
-	public static short valueToMetaFlag(String metaFlag) {
-
-		short result = 0;
-
-		for (TskData.TSK_FS_META_FLAG_ENUM flag : TskData.TSK_FS_META_FLAG_ENUM.values()) {
-			if (flag.toString().equals(metaFlag)) {
-				result = flag.getMetaFlag();
-			}
-		}
-		return result;
-	}
-
-	/**
-	 * Convert meta flag long to user-readable string / label
-	 *
-	 * @param metaFlag to convert
-	 * @return string formatted meta flag representation
-	 */
-	public static String metaFlagToString(short metaFlag) {
-
-		String result = "";
-
-		short allocFlag = TskData.TSK_FS_META_FLAG_ENUM.ALLOC.getMetaFlag();
-		short unallocFlag = TskData.TSK_FS_META_FLAG_ENUM.UNALLOC.getMetaFlag();
-
-		// some variables that might be needed in the future
-		//long usedFlag = TskData.TSK_FS_META_FLAG_ENUM.USED.getMetaFlag();
-		//long unusedFlag = TskData.TSK_FS_META_FLAG_ENUM.UNUSED.getMetaFlag();
-		//long compFlag = TskData.TSK_FS_META_FLAG_ENUM.COMP.getMetaFlag();
-		//long orphanFlag = TskData.TSK_FS_META_FLAG_ENUM.ORPHAN.getMetaFlag();
-
-		if ((metaFlag & allocFlag) == allocFlag) {
-			result = TskData.TSK_FS_META_FLAG_ENUM.ALLOC.getLabel();
-		}
-		if ((metaFlag & unallocFlag) == unallocFlag) {
-			result = TskData.TSK_FS_META_FLAG_ENUM.UNALLOC.getLabel();
-		}
-
-
-		return result;
-	}
-
-	/**
-	 * Convert mode and meta type to a user-displayable string
-	 *
-	 * @param mode mode attribute of the file/dir
-	 * @param metaType meta type attribute of the file/dir
-	 * @return converted, formatted user-displayable string
-	 */
-	public static String modeToString(short mode, short metaType) {
-
-		String result = "";
-
-		int metaTypeMax = TskData.TSK_FS_META_TYPE_ENUM.TSK_FS_META_TYPE_STR_MAX.getMetaType() & 0xff;
-
 		short isuid = TskData.TSK_FS_META_MODE_ENUM.TSK_FS_META_MODE_ISUID.getMode();
 		short isgid = TskData.TSK_FS_META_MODE_ENUM.TSK_FS_META_MODE_ISGID.getMode();
 		short isvtx = TskData.TSK_FS_META_MODE_ENUM.TSK_FS_META_MODE_ISVTX.getMode();
@@ -761,11 +434,7 @@ public abstract class FsContent extends AbstractFile {
 		short ixoth = TskData.TSK_FS_META_MODE_ENUM.TSK_FS_META_MODE_IXOTH.getMode();
 
 		// first character = the Meta Type
-		if ( (((int)metaType) & 0xff) < metaTypeMax) {
-			result += FsContent.metaTypeToString(metaType);
-		} else {
-			result += "-";
-		}
+		result += metaType.toString();
 
 		// second and third characters = user permissions
 		if ((mode & irusr) == irusr) {
@@ -855,4 +524,95 @@ public abstract class FsContent extends AbstractFile {
 		}
 		return result;
 	}
+
+	public boolean isModeSet(TSK_FS_META_MODE_ENUM mode) {
+		return modes.contains(mode);
+	}
+
+	/**
+	 * Get "known" file status - after running a HashDB ingest on it As marked
+	 * by a known file database, such as NSRL
+	 *
+	 * @return file known status enum value
+	 */
+	public FileKnown getKnown() {
+		return known;
+	}
+
+	/**
+	 * Get the absolute parent path string of this FsContent
+	 *
+	 * @return the parent path string
+	 */
+	public String getParentPath() {
+		return this.parentPath;
+	}
+
+	@Override
+	public synchronized String getUniquePath() throws TskCoreException {
+		if (uniquePath == null) {
+			StringBuilder sb = new StringBuilder();
+			sb.append(getFileSystem().getUniquePath());
+			sb.append(getParentPath());
+			sb.append(getName());
+			uniquePath = sb.toString();
+		}
+		return uniquePath;
+	}
+
+	/**
+	 * Get the md5 hash value as calculated, if present
+	 *
+	 * @return md5 hash string, if it is present or null if it is not
+	 */
+	public String getMd5Hash() {
+		return this.md5Hash;
+	}
+
+	@Override
+	public void finalize() throws Throwable {
+		try {
+			if (fileHandle != 0) {
+				SleuthkitJNI.closeFile(fileHandle);
+				fileHandle = 0;
+			}
+		} finally {
+			super.finalize();
+		}
+	}
+
+	/*
+	 * -------------------------------------------------------------------------
+	 * Util methods to convert / map the data
+	 * -------------------------------------------------------------------------
+	 */
+	/**
+	 * Return the epoch into string in ISO 8601 dateTime format
+	 *
+	 * @param epoch time in seconds
+	 * @return formatted date time string as "yyyy-MM-dd HH:mm:ss"
+	 */
+	public static String epochToTime(long epoch) {
+		String time = "0000-00-00 00:00:00";
+		if (epoch != 0) {
+			time = new java.text.SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new java.util.Date(epoch * 1000));
+		}
+		return time;
+	}
+
+	/**
+	 * Convert from ISO 8601 formatted date time string to epoch time in seconds
+	 *
+	 * @param time formatted date time string as "yyyy-MM-dd HH:mm:ss"
+	 * @return epoch time in seconds
+	 */
+	public static long timeToEpoch(String time) {
+		long epoch = 0;
+		try {
+			epoch = new java.text.SimpleDateFormat("yyyy-MM-dd HH:mm:ss").parse(time).getTime() / 1000;
+		} catch (Exception e) {
+		}
+
+		return epoch;
+	}
 }
