@@ -40,21 +40,10 @@ public class LayoutFile extends AbstractFile{
 	//layout ranges associated with this file
 	private List<TskFileRange> ranges;
 	
-    private Content parent;
-	
 	protected LayoutFile(SleuthkitCase db, long obj_id, String name, TskData.TSK_DB_FILES_TYPE_ENUM type) {
 		super(db, obj_id, name, type);
 	}
-	
-	/**
-     * Set the parent class, will be called by the parent
-	 * 
-     * @param p parent
-     */
-    protected void setParent(Content p){
-        parent = p;
-    }
-	
+
 	/**
 	 * Get number of file layout ranges associated with this layout file
 	 * @return number of file layout ranges objects associated
@@ -69,8 +58,6 @@ public class LayoutFile extends AbstractFile{
 		return size;
 	}
 
-	
-
 	@Override
 	public List<TskFileRange> getRanges() throws TskCoreException {
 		if(ranges == null) {
@@ -79,7 +66,6 @@ public class LayoutFile extends AbstractFile{
         return ranges;
 	}
 
-
 	@Override
 	public List<Content> getChildren() throws TskCoreException {
 		return Collections.<Content>emptyList();
@@ -188,15 +174,6 @@ public class LayoutFile extends AbstractFile{
 	public <T> T accept(SleuthkitItemVisitor<T> v) {
 		return v.visit(this);
 	}
-	
-	/**
-	 * Get parent content object (either filesystem, or volume)
-	 * @return the parent content object
-	 */
-	public Content getParent() {
-		return parent;
-	}
-	
 
 	@Override
 	public Image getImage() throws TskCoreException{
@@ -207,4 +184,9 @@ public class LayoutFile extends AbstractFile{
 	public boolean isVirtual() {
 		return true;
 	}
+	
+	@Override
+	public boolean isRoot() {
+		return false;
+	}
 }
