@@ -2,6 +2,11 @@ package org.sleuthkit.datamodel;
 
 import java.sql.ResultSet;
 import java.sql.SQLException;
+import org.sleuthkit.datamodel.TskData.FileKnown;
+import org.sleuthkit.datamodel.TskData.TSK_FS_ATTR_TYPE_ENUM;
+import org.sleuthkit.datamodel.TskData.TSK_FS_META_TYPE_ENUM;
+import org.sleuthkit.datamodel.TskData.TSK_FS_NAME_FLAG_ENUM;
+import org.sleuthkit.datamodel.TskData.TSK_FS_NAME_TYPE_ENUM;
 
 /**
  * Database helper class the wraps most of the mappings from ResultSet to
@@ -64,7 +69,7 @@ class ResultSetHelper {
 		long imgOffset = rs.getLong("img_offset");
 		long blockSize = rs.getLong("block_size");
 
-		VolumeSystem vs = new VolumeSystem(db, id, "Volume System", type, imgOffset, blockSize);
+		VolumeSystem vs = new VolumeSystem(db, id, "", type, imgOffset, blockSize);
 
 		vs.setParent(parent);
 		return vs;
@@ -96,7 +101,7 @@ class ResultSetHelper {
 	FileSystem fileSystem(ResultSet rs, Content parent) throws SQLException {
 
 		TskData.TSK_FS_TYPE_ENUM fsType = TskData.TSK_FS_TYPE_ENUM.valueOf(rs.getInt("fs_type"));
-		FileSystem fs = new FileSystem(db, rs.getLong("obj_id"), "File System", rs.getLong("img_offset"),
+		FileSystem fs = new FileSystem(db, rs.getLong("obj_id"), "", rs.getLong("img_offset"),
 				fsType, rs.getLong("block_size"), rs.getLong("block_count"),
 				rs.getLong("root_inum"), rs.getLong("first_inum"), rs.getLong("last_inum"));
 		fs.setParent(parent);
@@ -111,11 +116,11 @@ class ResultSetHelper {
 	 * @throws SQLException 
 	 */
 	File file(ResultSet rs, FileSystem fs) throws SQLException {
-		File f = new File(db, rs.getLong("obj_id"), rs.getLong("fs_obj_id"), rs.getLong("meta_addr"), rs.getShort("attr_type"),
-				rs.getShort("attr_id"), rs.getString("name"), rs.getShort("dir_type"),
-				rs.getShort("meta_type"), rs.getShort("dir_flags"), rs.getShort("meta_flags"), rs.getLong("size"),
+		File f = new File(db, rs.getLong("obj_id"), rs.getLong("fs_obj_id"), rs.getLong("meta_addr"), TSK_FS_ATTR_TYPE_ENUM.valueOf(rs.getShort("attr_type")),
+				rs.getShort("attr_id"), rs.getString("name"), TSK_FS_NAME_TYPE_ENUM.valueOf(rs.getShort("dir_type")),
+				TSK_FS_META_TYPE_ENUM.ValueOf(rs.getShort("meta_type")), TSK_FS_NAME_FLAG_ENUM.valueOf(rs.getShort("dir_flags")), rs.getShort("meta_flags"), rs.getLong("size"),
 				rs.getLong("ctime"), rs.getLong("crtime"), rs.getLong("atime"), rs.getLong("mtime"),
-				rs.getShort("mode"), rs.getInt("uid"), rs.getInt("gid"), rs.getByte("known"), rs.getString("parent_path"), rs.getString("md5"));
+				rs.getShort("mode"), rs.getInt("uid"), rs.getInt("gid"), FileKnown.valueOf(rs.getByte("known")), rs.getString("parent_path"), rs.getString("md5"));
 		f.setFileSystem(fs);
 		return f;
 	}
@@ -129,11 +134,11 @@ class ResultSetHelper {
 	 * @throws SQLException thrown if SQL error occurred
 	 */
 	Directory directory(ResultSet rs, FileSystem fs, String name) throws SQLException {
-		Directory dir = new Directory(db, rs.getLong("obj_id"), rs.getLong("fs_obj_id"), rs.getLong("meta_addr"), rs.getShort("attr_type"),
-				rs.getShort("attr_id"), name, rs.getShort("dir_type"),
-				rs.getShort("meta_type"), rs.getShort("dir_flags"), rs.getShort("meta_flags"), rs.getLong("size"),
+		Directory dir = new Directory(db, rs.getLong("obj_id"), rs.getLong("fs_obj_id"), rs.getLong("meta_addr"), TSK_FS_ATTR_TYPE_ENUM.valueOf(rs.getShort("attr_type")),
+				rs.getShort("attr_id"), name, TSK_FS_NAME_TYPE_ENUM.valueOf(rs.getShort("dir_type")),
+				TSK_FS_META_TYPE_ENUM.ValueOf(rs.getShort("meta_type")), TSK_FS_NAME_FLAG_ENUM.valueOf(rs.getShort("dir_flags")), rs.getShort("meta_flags"), rs.getLong("size"),
 				rs.getLong("ctime"), rs.getLong("crtime"), rs.getLong("atime"), rs.getLong("mtime"),
-				rs.getShort("mode"), rs.getInt("uid"), rs.getInt("gid"), rs.getByte("known"), rs.getString("parent_path"), rs.getString("md5"));
+				rs.getShort("mode"), rs.getInt("uid"), rs.getInt("gid"), FileKnown.valueOf(rs.getByte("known")), rs.getString("parent_path"), rs.getString("md5"));
 		dir.setFileSystem(fs);
 		return dir;
 	}
