@@ -16,7 +16,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.sleuthkit.datamodel;
 
 import java.text.DateFormat;
@@ -25,119 +24,159 @@ import java.util.GregorianCalendar;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.TimeZone;
+import org.sleuthkit.datamodel.TskData.TSK_FS_ATTR_TYPE_ENUM;
 
 /**
- * Interfaces with the Sleuthkit TSK c/c++ libraries
- * Supports case management, add image process,
- * reading data off content objects
- * Setting up Hash database parameters and updating / reading values
- * 
- * Caches image and filesystem handles and reuses them for the duration of the application
+ * Interfaces with the Sleuthkit TSK c/c++ libraries Supports case management,
+ * add image process, reading data off content objects Setting up Hash database
+ * parameters and updating / reading values
+ *
+ * Caches image and filesystem handles and reuses them for the duration of the
+ * application
  */
 public class SleuthkitJNI {
+
 	private static final int MAX_DATABASES = 256;
-	
+
 	//Native methods
 	private static native String getVersionNat();
+
 	private static native void startVerboseLoggingNat(String logPath);
-	
+
 	//database
 	private static native long newCaseDbNat(String dbPath) throws TskCoreException;
+
 	private static native long openCaseDbNat(String path) throws TskCoreException;
+
 	private static native void closeCaseDbNat(long db) throws TskCoreException;
+
 	private static native int setDbNSRLNat(String hashDbPath) throws TskCoreException;
+
 	private static native int addDbKnownBadNat(String hashDbPath) throws TskCoreException;
+
 	private static native String getDbName(String hashDbPath) throws TskCoreException;
+
 	private static native void closeDbLookupsNat() throws TskCoreException;
+
 	private static native int knownBadDbLookup(String hash, int dbHandle) throws TskCoreException;
+
 	private static native int nsrlDbLookup(String hash) throws TskCoreException;
+
 	private static native int getIndexSizeNat(String hashDbPath) throws TskCoreException;
 
-	
 	//load image
 	private static native long initAddImgNat(long db, String timezone, boolean processUnallocSpace, boolean noFatFsOrphans) throws TskCoreException;
+
 	private static native void runAddImgNat(long process, String[] imgPath, int splits, String timezone) throws TskCoreException, TskDataException; // if runAddImg finishes without being stopped, revertAddImg or commitAddImg MUST be called
+
 	private static native void stopAddImgNat(long process) throws TskCoreException;
+
 	private static native void revertAddImgNat(long process) throws TskCoreException;
+
 	private static native long commitAddImgNat(long process) throws TskCoreException;
+
 	//open functions
 	private static native long openImgNat(String[] imgPath, int splits) throws TskCoreException;
+
 	private static native long openVsNat(long imgHandle, long vsOffset) throws TskCoreException;
+
 	private static native long openVolNat(long vsHandle, long volId) throws TskCoreException;
+
 	private static native long openFsNat(long imgHandle, long fsId) throws TskCoreException;
+
 	private static native long openFileNat(long fsHandle, long fileId, int attrType, int attrId) throws TskCoreException;
- 
+
 	//read functions
 	private static native int readImgNat(long imgHandle, byte[] readBuffer, long offset, long len) throws TskCoreException;
+
 	private static native int readVsNat(long vsHandle, byte[] readBuffer, long offset, long len) throws TskCoreException;
+
 	private static native int readVolNat(long volHandle, byte[] readBuffer, long offset, long len) throws TskCoreException;
+
 	private static native int readFsNat(long fsHandle, byte[] readBuffer, long offset, long len) throws TskCoreException;
+
 	private static native int readFileNat(long fileHandle, byte[] readBuffer, long offset, long len) throws TskCoreException;
 
 	//close functions
 	private static native void closeImgNat(long imgHandle);
+
 	private static native void closeVsNat(long vsHandle);
+
 	private static native void closeFsNat(long fsHandle);
+
 	private static native void closeFileNat(long fileHandle);
-	
+
 	//hash-lookup database functions
 	private static native void createLookupIndexNat(String dbPath) throws TskCoreException;
+
 	private static native boolean lookupIndexExistsNat(String dbPath) throws TskCoreException;
-	
+
 	//util functions
 	private static native long findDeviceSizeNat(String devicePath) throws TskCoreException;
 
+	private static native String getCurDirNat(long process);
+
 	//Linked library loading
 	static {
 		try {
 			System.loadLibrary("zlib");
-			System.loadLibrary("libewf");
-		}
-		catch (UnsatisfiedLinkError e) {
-			System.out.println("Error loading zlib/libewf libraries, " + e.toString());
+		} catch (UnsatisfiedLinkError e) {
+			System.out.println("SleuthkitJNI: error loading zlib library, " + e.toString());
 		}
 		
+		try {
+			System.loadLibrary("libewf");
+		} catch (UnsatisfiedLinkError e) {
+			System.out.println("SleuthkitJNI: error loading libewf library, " + e.toString());
+		}
+
 		/* We should rename the Windows dll, to remove the lib prefix.
 		 * First try windows version of the name and then try Unix-style.
 		 */
 		try {
 			System.loadLibrary("libtsk_jni");
+		} catch (UnsatisfiedLinkError e1) {
+			try {
+				System.loadLibrary("tsk_jni");
+			} catch (UnsatisfiedLinkError e2) {
+				System.out.println("SleuthkitJNI: Error loading tsk_jni library " + e2.toString());
+			}
 		}
-		catch (UnsatisfiedLinkError e) {
-			System.loadLibrary("tsk_jni");
-		} 
 	}
 
-
-	public SleuthkitJNI() {}
-	
+	public SleuthkitJNI() {
+	}
 
 	/**
 	 * Handle to TSK Case database
 	 */
 	public static class CaseDbHandle {
+
 		private long caseDbPointer;
-		
 		//map concat. image paths to cached image handle
-		private static final Map<String,Long> imageHandleCache = new HashMap<String,Long>(); 
+		private static final Map<String, Long> imageHandleCache = new HashMap<String, Long>();
 		//map image and offsets to cached fs handle
-		private static final Map<Long,Map<Long,Long>> fsHandleCache = new HashMap<Long,Map<Long,Long>>();
-		
+		private static final Map<Long, Map<Long, Long>> fsHandleCache = new HashMap<Long, Map<Long, Long>>();
+
 		private CaseDbHandle(long pointer) {
 			this.caseDbPointer = pointer;
 		}
-		
+
 		/**
 		 * Close the case database
-		 * @throws TskCoreException exception thrown if critical error occurs within TSK 
+		 *
+		 * @throws TskCoreException exception thrown if critical error occurs
+		 * within TSK
 		 */
 		void free() throws TskCoreException {
 			SleuthkitJNI.closeCaseDbNat(caseDbPointer);
 		}
-		
+
 		/**
 		 * Clear currently set lookup databases within TSK
-		 * @throws TskCoreException exception thrown if critical error occurs within TSK
+		 *
+		 * @throws TskCoreException exception thrown if critical error occurs
+		 * within TSK
 		 */
 		void clearLookupDatabases() throws TskCoreException {
 			closeDbLookupsNat();
@@ -145,6 +184,7 @@ public class SleuthkitJNI {
 
 		/**
 		 * Set the NSRL database
+		 *
 		 * @param path The path to the database
 		 * @return a handle for that database
 		 */
@@ -154,6 +194,7 @@ public class SleuthkitJNI {
 
 		/**
 		 * Add the known bad database
+		 *
 		 * @param path The path to the database
 		 * @return a handle for that database
 		 */
@@ -161,141 +202,168 @@ public class SleuthkitJNI {
 			return addDbKnownBadNat(path);
 		}
 
-		
-	
 		/**
 		 * Start the process of adding a disk image to the case
-		 * 
+		 *
 		 * @param timezone Timezone that image was from
-		 * @param processUnallocSpace true if to process unallocated space in the image
-		 * @param noFatFsOrphans true if to skip processing of orphans on FAT filesystems 
-		 * 
+		 * @param processUnallocSpace true if to process unallocated space in
+		 * the image
+		 * @param noFatFsOrphans true if to skip processing of orphans on FAT
+		 * filesystems
+		 *
 		 * @return Object that can be used to manage the process.
 		 */
 		AddImageProcess initAddImageProcess(String timezone, boolean processUnallocSpace, boolean noFatFsOrphans) {
 			return new AddImageProcess(timezone, processUnallocSpace, noFatFsOrphans);
 		}
-		
+
 		/**
-		 * Encapsulates a multi-step process to add a disk image.
-		 * Adding a disk image takes a while and this object
-		 * has objects to manage that process.
+		 * Encapsulates a multi-step process to add a disk image. Adding a disk
+		 * image takes a while and this object has objects to manage that
+		 * process. Methods within this class are intended to be threadsafe.
 		 */
 		public class AddImageProcess {
-			String timezone;
-			boolean processUnallocSpace;
-			boolean noFatFsOrphans;
-			long autoDbPointer;
-			
+
+			private String timezone;
+			private boolean processUnallocSpace;
+			private boolean noFatFsOrphans;
+			private volatile long autoDbPointer;
+
 			private AddImageProcess(String timezone, boolean processUnallocSpace, boolean noFatFsOrphans) {
 				this.timezone = timezone;
 				this.processUnallocSpace = processUnallocSpace;
 				this.noFatFsOrphans = noFatFsOrphans;
 				autoDbPointer = 0;
 			}
-			
+
 			/**
-			 * Start the process of adding an image to the case database. 
-			 * MUST call either commit() or revert() after calling run().
+			 * Start the process of adding an image to the case database. MUST
+			 * call either commit() or revert() after calling run().
+			 *
 			 * @param imgPath Full path(s) to the image file(s).
-			 * @throws TskCoreException exception thrown if critical error occurs within TSK 
-			 * @throws TskDataException exception thrown if non-critical error occurs within TSK (should be OK to continue)
+			 * @throws TskCoreException exception thrown if critical error
+			 * occurs within TSK
+			 * @throws TskDataException exception thrown if non-critical error
+			 * occurs within TSK (should be OK to continue)
 			 */
 			public void run(String[] imgPath) throws TskCoreException, TskDataException {
 				if (autoDbPointer != 0) {
 					throw new TskCoreException("AddImgProcess:run: AutoDB pointer is already set");
 				}
-				
-				autoDbPointer = initAddImgNat(caseDbPointer, longToShort(timezone), processUnallocSpace, noFatFsOrphans);
+
+				synchronized (this) {
+					autoDbPointer = initAddImgNat(caseDbPointer, timezoneLongToShort(timezone), processUnallocSpace, noFatFsOrphans);
+				}
 				if (autoDbPointer == 0) {
 					//additional check in case initAddImgNat didn't throw exception
 					throw new TskCoreException("AddImgProcess::run: AutoDB pointer is NULL after initAddImgNat");
 				}
 				runAddImgNat(autoDbPointer, imgPath, imgPath.length, timezone);
 			}
-			
+
 			/**
 			 * Call while run() is executing in another thread to prematurely
-			 * halt the process. Must call revert() in the other thread once
-			 * the stopped run() returns.
-			 * @throws TskCoreException exception thrown if critical error occurs within TSK
+			 * halt the process. Must call revert() in the other thread once the
+			 * stopped run() returns.
+			 *
+			 * @throws TskCoreException exception thrown if critical error
+			 * occurs within TSK
 			 */
 			public void stop() throws TskCoreException {
 				if (autoDbPointer == 0) {
 					throw new TskCoreException("AddImgProcess::stop: AutoDB pointer is NULL");
 				}
-				
+
 				stopAddImgNat(autoDbPointer);
 			}
-			
+
 			/**
 			 * Rollback a process that has already been run(), reverting the
-			 * database.  This releases the C++ object and no additional 
-			 * operations can be performed. 
-			 * 
-			 * @throws TskCoreException exception thrown if critical error occurs within TSK
+			 * database. This releases the C++ object and no additional
+			 * operations can be performed. This method is threadsafe.
+			 *
+			 * @throws TskCoreException exception thrown if critical error
+			 * occurs within TSK
 			 */
-			public void revert() throws TskCoreException {
+			public synchronized void revert() throws TskCoreException {
 				if (autoDbPointer == 0) {
 					throw new TskCoreException("AddImgProcess::revert: AutoDB pointer is NULL");
 				}
-				
+
 				revertAddImgNat(autoDbPointer);
 				// the native code deleted the object
 				autoDbPointer = 0;
 			}
-			
+
 			/**
 			 * Finish off a process that has already been run(), closing the
 			 * transaction and committing the new image data to the database.
-			 * @return The id of the image that was added. This releases the 
-			 * C++ object and no additional operations can be performed. 
-			 * @throws TskCoreException exception thrown if critical error occurs within TSK 
+			 *
+			 * @return The id of the image that was added. This releases the C++
+			 * object and no additional operations can be performed. This method
+			 * is threadsafe.
+			 *
+			 * @throws TskCoreException exception thrown if critical error
+			 * occurs within TSK
 			 */
-			public long commit() throws TskCoreException {
+			public synchronized long commit() throws TskCoreException {
 				if (autoDbPointer == 0) {
 					throw new TskCoreException("AddImgProcess::commit: AutoDB pointer is NULL");
 				}
-	
+
 				long id = commitAddImgNat(autoDbPointer);
 				// the native code deleted the object
 				autoDbPointer = 0;
 				return id;
 			}
+
+			/**
+			 * Gets the directory currently being processed by TSK. This method
+			 * is threadsafe.
+			 *
+			 * @return the currently processing directory
+			 */
+			public synchronized String currentDirectory() {
+				return autoDbPointer == 0 ? "NO_INFO" : getCurDirNat(autoDbPointer);
+			}
 		}
 	}
-	
+
 	/**
 	 * Creates a new case database. Must call .free() on CaseDbHandle instance
 	 * when done.
+	 *
 	 * @param path Location to create the database at.
 	 * @return Handle for a new TskCaseDb instance.
-	 * @throws TskCoreException exception thrown if critical error occurs within TSK 
+	 * @throws TskCoreException exception thrown if critical error occurs within
+	 * TSK
 	 */
 	static CaseDbHandle newCaseDb(String path) throws TskCoreException {
 		return new CaseDbHandle(newCaseDbNat(path));
 	}
-	
+
 	/**
-	 * Opens an existing case database. Must call .free() on CaseDbHandle 
+	 * Opens an existing case database. Must call .free() on CaseDbHandle
 	 * instance when done.
+	 *
 	 * @param path Location of the existing database.
 	 * @return Handle for a new TskCaseDb instance.
-	 * @throws TskCoreException exception thrown if critical error occurs within TSK 
+	 * @throws TskCoreException exception thrown if critical error occurs within
+	 * TSK
 	 */
 	static CaseDbHandle openCaseDb(String path) throws TskCoreException {
 		return new CaseDbHandle(openCaseDbNat(path));
 	}
-	
 
 	/**
 	 * get the Sleuth Kit version string
+	 *
 	 * @return the version string
 	 */
-	public static String getVersion(){
+	public static String getVersion() {
 		return getVersionNat();
 	}
-	
+
 	/**
 	 * Enable verbose logging and redirect stderr to the given log file.
 	 */
@@ -303,77 +371,82 @@ public class SleuthkitJNI {
 		startVerboseLoggingNat(logPath);
 	}
 
-
 	/**
 	 * open the image and return the image info pointer
+	 *
 	 * @param imageFiles the paths to the images
 	 * @return the image info pointer
-	 * @throws TskCoreException exception thrown if critical error occurs within TSK
+	 * @throws TskCoreException exception thrown if critical error occurs within
+	 * TSK
 	 */
-	public synchronized static long openImage(String[] imageFiles) throws TskCoreException{
+	public synchronized static long openImage(String[] imageFiles) throws TskCoreException {
 		long imageHandle = 0;
-		
+
 		StringBuilder keyBuilder = new StringBuilder();
-		for (int i=0; i<imageFiles.length; ++i)
+		for (int i = 0; i < imageFiles.length; ++i) {
 			keyBuilder.append(imageFiles[i]);
+		}
 		final String imageKey = keyBuilder.toString();
-		
-		if (CaseDbHandle.imageHandleCache.containsKey(imageKey) )
-			//get from cache
+
+		if (CaseDbHandle.imageHandleCache.containsKey(imageKey)) //get from cache
+		{
 			imageHandle = CaseDbHandle.imageHandleCache.get(imageKey);
-		else {
+		} else {
 			//open new handle and cache it
 			imageHandle = openImgNat(imageFiles, imageFiles.length);
-			CaseDbHandle.fsHandleCache.put(imageHandle, new HashMap<Long,Long>());
+			CaseDbHandle.fsHandleCache.put(imageHandle, new HashMap<Long, Long>());
 			CaseDbHandle.imageHandleCache.put(imageKey, imageHandle);
 		}
 
 		return imageHandle;
-		
+
 	}
 
 	/**
 	 * Get volume system Handle
+	 *
 	 * @param imgHandle a handle to previously opened image
 	 * @param vsOffset byte offset in the image to the volume system (usually 0)
 	 * @return pointer to a vsHandle structure in the sleuthkit
-	 * @throws TskCoreException exception thrown if critical error occurs within TSK
+	 * @throws TskCoreException exception thrown if critical error occurs within
+	 * TSK
 	 */
-	public static long openVs(long imgHandle, long vsOffset) throws TskCoreException{
+	public static long openVs(long imgHandle, long vsOffset) throws TskCoreException {
 		return openVsNat(imgHandle, vsOffset);
 	}
 
 	//get pointers
 	/**
 	 * Get volume Handle
+	 *
 	 * @param vsHandle pointer to the volume system structure in the sleuthkit
 	 * @param volId id of the volume
 	 * @return pointer to a volHandle structure in the sleuthkit
-	 * @throws TskCoreException exception thrown if critical error occurs within TSK  
+	 * @throws TskCoreException exception thrown if critical error occurs within
+	 * TSK
 	 */
-	public static long openVsPart(long vsHandle, long volId) throws TskCoreException{
+	public static long openVsPart(long vsHandle, long volId) throws TskCoreException {
 		//returned long is ptr to vs Handle object in tsk
 		return openVolNat(vsHandle, volId);
 	}
 
 	/**
-	 * Get file system Handle
-	 * Opened handle is cached (transparently) so it does not need be reopened next time
-	 * for the duration of the application
-	 * 
+	 * Get file system Handle Opened handle is cached (transparently) so it does
+	 * not need be reopened next time for the duration of the application
+	 *
 	 * @param imgHandle pointer to imgHandle in sleuthkit
 	 * @param fsOffset byte offset to the file system
 	 * @return pointer to a fsHandle structure in the sleuthkit
-	 * @throws TskCoreException exception thrown if critical error occurs within TSK  
+	 * @throws TskCoreException exception thrown if critical error occurs within
+	 * TSK
 	 */
-	public synchronized static long openFs(long imgHandle, long fsOffset) throws TskCoreException{
+	public synchronized static long openFs(long imgHandle, long fsOffset) throws TskCoreException {
 		long fsHandle = 0;
-		final Map<Long,Long> imgOffSetToFsHandle = CaseDbHandle.fsHandleCache.get(imgHandle);
+		final Map<Long, Long> imgOffSetToFsHandle = CaseDbHandle.fsHandleCache.get(imgHandle);
 		if (imgOffSetToFsHandle.containsKey(fsOffset)) {
 			//return cached
 			fsHandle = imgOffSetToFsHandle.get(fsOffset);
-		}
-		else {
+		} else {
 			fsHandle = openFsNat(imgHandle, fsOffset);
 			//cache it
 			imgOffSetToFsHandle.put(fsOffset, fsHandle);
@@ -383,80 +456,98 @@ public class SleuthkitJNI {
 
 	/**
 	 * Get file Handle
-	 * 
+	 *
 	 * @param fsHandle fsHandle pointer in the sleuthkit
 	 * @param fileId id of the file
 	 * @param attrType file attribute type to open
 	 * @param attrId file attribute id to open
 	 * @return pointer to a file structure in the sleuthkit
-	 * @throws TskCoreException exception thrown if critical error occurs within TSK  
+	 * @throws TskCoreException exception thrown if critical error occurs within
+	 * TSK
 	 */
-	public static long openFile(long fsHandle, long fileId, int attrType, int attrId) throws TskCoreException{
-		return openFileNat(fsHandle, fileId, attrType, attrId);
+	public static long openFile(long fsHandle, long fileId, TSK_FS_ATTR_TYPE_ENUM attrType, int attrId) throws TskCoreException {
+		return openFileNat(fsHandle, fileId, attrType.getValue(), attrId);
 	}
 
 	//do reads
 	/**
 	 * reads data from an image
-	 * @param imgHandle 
+	 *
+	 * @param imgHandle
 	 * @param readBuffer buffer to read to
 	 * @param offset byte offset in the image to start at
 	 * @param len amount of data to read
-	 * @return the number of characters read, or -1 if the end of the stream has been reached 
-	 * @throws TskCoreException exception thrown if critical error occurs within TSK
+	 * @return the number of characters read, or -1 if the end of the stream has
+	 * been reached
+	 * @throws TskCoreException exception thrown if critical error occurs within
+	 * TSK
 	 */
-	public static int readImg(long imgHandle, byte[] readBuffer, long offset, long len) throws TskCoreException{
+	public static int readImg(long imgHandle, byte[] readBuffer, long offset, long len) throws TskCoreException {
 		//returned byte[] is the data buffer
 		return readImgNat(imgHandle, readBuffer, offset, len);
 	}
+
 	/**
 	 * reads data from an volume system
+	 *
 	 * @param vsHandle pointer to a volume system structure in the sleuthkit
 	 * @param readBuffer buffer to read to
 	 * @param offset sector offset in the image to start at
 	 * @param len amount of data to read
-	 * @return the number of characters read, or -1 if the end of the stream has been reached 
-	 * @throws TskCoreException exception thrown if critical error occurs within TSK  
+	 * @return the number of characters read, or -1 if the end of the stream has
+	 * been reached
+	 * @throws TskCoreException exception thrown if critical error occurs within
+	 * TSK
 	 */
-	public static int readVs(long vsHandle, byte[] readBuffer, long offset, long len) throws TskCoreException{
+	public static int readVs(long vsHandle, byte[] readBuffer, long offset, long len) throws TskCoreException {
 		return readVsNat(vsHandle, readBuffer, offset, len);
 	}
+
 	/**
 	 * reads data from an volume
+	 *
 	 * @param volHandle pointer to a volume structure in the sleuthkit
 	 * @param readBuffer buffer to read to
 	 * @param offset byte offset in the image to start at
 	 * @param len amount of data to read
-	 * @return the number of characters read, or -1 if the end of the stream has been reached 
-	 * @throws TskCoreException exception thrown if critical error occurs within TSK  
+	 * @return the number of characters read, or -1 if the end of the stream has
+	 * been reached
+	 * @throws TskCoreException exception thrown if critical error occurs within
+	 * TSK
 	 */
-	public static int readVsPart(long volHandle, byte[] readBuffer, long offset, long len) throws TskCoreException{
+	public static int readVsPart(long volHandle, byte[] readBuffer, long offset, long len) throws TskCoreException {
 		//returned byte[] is the data buffer
 		return readVolNat(volHandle, readBuffer, offset, len);
 	}
+
 	/**
 	 * reads data from an file system
+	 *
 	 * @param fsHandle pointer to a file system structure in the sleuthkit
 	 * @param readBuffer buffer to read to
 	 * @param offset byte offset in the image to start at
 	 * @param len amount of data to read
-	 * @return the number of characters read, or -1 if the end of the stream has been reached 
-	 * @throws TskCoreException exception thrown if critical error occurs within TSK  
+	 * @return the number of characters read, or -1 if the end of the stream has
+	 * been reached
+	 * @throws TskCoreException exception thrown if critical error occurs within
+	 * TSK
 	 */
-	public static int readFs(long fsHandle, byte[] readBuffer, long offset, long len) throws TskCoreException{
+	public static int readFs(long fsHandle, byte[] readBuffer, long offset, long len) throws TskCoreException {
 		//returned byte[] is the data buffer
 		return readFsNat(fsHandle, readBuffer, offset, len);
 	}
-	
-	
+
 	/**
 	 * reads data from an file
+	 *
 	 * @param fileHandle pointer to a file structure in the sleuthkit
 	 * @param readBuffer pre-allocated buffer to read to
 	 * @param offset byte offset in the image to start at
 	 * @param len amount of data to read
-	 * @return the number of characters read, or -1 if the end of the stream has been reached 
-	 * @throws TskCoreException exception thrown if critical error occurs within TSK  
+	 * @return the number of characters read, or -1 if the end of the stream has
+	 * been reached
+	 * @throws TskCoreException exception thrown if critical error occurs within
+	 * TSK
 	 */
 	public static int readFile(long fileHandle, byte[] readBuffer, long offset, long len) throws TskCoreException {
 		return readFileNat(fileHandle, readBuffer, offset, len);
@@ -464,65 +555,71 @@ public class SleuthkitJNI {
 
 	//free pointers
 	/**
-	 * frees the imgHandle pointer
-	 * currently does not close the image, until the application terminates (image handle is cached)
-	 * 
+	 * frees the imgHandle pointer currently does not close the image, until the
+	 * application terminates (image handle is cached)
+	 *
 	 * @param imgHandle to close the image
 	 */
-	public static void closeImg(long imgHandle){
+	public static void closeImg(long imgHandle) {
 		//@@@ TODO close the image handle when Case is closed instead
 		//currently the image handle is not being freed, it's cached for duration of the application
 		//closeImgNat(imgHandle); 
 	}
+
 	/**
 	 * frees the vsHandle pointer
+	 *
 	 * @param vsHandle pointer to volume system structure in sleuthkit
 	 */
-	public static void closeVs(long vsHandle){
+	public static void closeVs(long vsHandle) {
 		closeVsNat(vsHandle);
 	}
 
 	/**
-	 * frees the fsHandle pointer
-	 * Currently does not do anything - preserves the cached object for the duration of the application
-	 * 
+	 * frees the fsHandle pointer Currently does not do anything - preserves the
+	 * cached object for the duration of the application
+	 *
 	 * @param fsHandle pointer to file system structure in sleuthkit
 	 */
-	public static void closeFs(long fsHandle){
+	public static void closeFs(long fsHandle) {
 		//@@@ TODO close the fs handle when Case is closed instead
 		//currently the fs handle is not being freed, it's cached for duration of the application
 		//closeFsNat(fsHandle);
 	}
-	
+
 	/**
 	 * frees the fileHandle pointer
+	 *
 	 * @param fileHandle pointer to file structure in sleuthkit
 	 */
-	public static void closeFile(long fileHandle){
+	public static void closeFile(long fileHandle) {
 		closeFileNat(fileHandle);
 	}
-	
+
 	/**
 	 * Create an index for the given database path.
+	 *
 	 * @param dbPath The path to the database
 	 * @throws TskCoreException if a critical error occurs within TSK core
 	 */
 	public static void createLookupIndex(String dbPath) throws TskCoreException {
 		createLookupIndexNat(dbPath);
 	}
-	
+
 	/**
 	 * Check if an index exists for the given database path.
+	 *
 	 * @param dbPath
 	 * @return true if index exists
-	 * @throws TskCoreException if a critical error occurs within TSK core 
+	 * @throws TskCoreException if a critical error occurs within TSK core
 	 */
 	public static boolean lookupIndexExists(String dbPath) throws TskCoreException {
 		return lookupIndexExistsNat(dbPath);
 	}
-	
+
 	/**
 	 * Set the NSRL database
+	 *
 	 * @param path The path to the database
 	 * @return a handle for that database
 	 * @throws TskCoreException if a critical error occurs within TSK core
@@ -533,6 +630,7 @@ public class SleuthkitJNI {
 
 	/**
 	 * Add the known bad database
+	 *
 	 * @param path The path to the database
 	 * @return a handle for that database
 	 * @throws TskCoreException if a critical error occurs within TSK core
@@ -543,51 +641,59 @@ public class SleuthkitJNI {
 
 	/**
 	 * Get the name of the database
+	 *
 	 * @param path The path to the database
 	 * @throws TskCoreException if a critical error occurs within TSK core
 	 */
 	public static String getDatabaseName(String path) throws TskCoreException {
 		return getDbName(path);
 	}
-	
+
 	/**
 	 * Look up the given hash in the NSRL database
+	 *
 	 * @param hash
 	 * @return the status of the hash in the NSRL
-	 * @throws TskCoreException if a critical error occurs within TSK core 
+	 * @throws TskCoreException if a critical error occurs within TSK core
 	 */
-	public static TskData.FileKnown nsrlHashLookup(String hash) throws TskCoreException{
-		return TskData.FileKnown.valueOf((byte)nsrlDbLookup(hash));
+	public static TskData.FileKnown nsrlHashLookup(String hash) throws TskCoreException {
+		return TskData.FileKnown.valueOf((byte) nsrlDbLookup(hash));
 	}
-	
+
 	/**
 	 * Look up the given hash in the known bad database
+	 *
 	 * @param hash
 	 * @param dbHandle previously opened hash db handle
 	 * @return the status of the hash in the known bad database
-	 * @throws TskCoreException if a critical error occurs within TSK core 
+	 * @throws TskCoreException if a critical error occurs within TSK core
 	 */
-	public static TskData.FileKnown knownBadHashLookup(String hash, int dbHandle) throws TskCoreException{
-		return TskData.FileKnown.valueOf((byte)knownBadDbLookup(hash, dbHandle));
+	public static TskData.FileKnown knownBadHashLookup(String hash, int dbHandle) throws TskCoreException {
+		return TskData.FileKnown.valueOf((byte) knownBadDbLookup(hash, dbHandle));
 	}
-	
+
 	/**
 	 * Get the size of the index of the given database
+	 *
 	 * @param path the path to the database
 	 * @return the size of the index or -1 if it doesn't exist
 	 * @throws TskCoreException
 	 */
-	public static int getIndexSize(String path) throws TskCoreException{
+	public static int getIndexSize(String path) throws TskCoreException {
 		return getIndexSizeNat(path);
 	}
-	
+
 	/**
 	 * Convert this timezone from long to short form
-	 * 
+	 *
 	 * @param timezone the long form (e.g., America/New_York)
 	 * @return the short form (e.g., EST5EDT)
 	 */
-	private static String longToShort(String timezone) {
+	private static String timezoneLongToShort(String timezone) {
+		if (timezone == null || timezone.isEmpty()) {
+			return "";
+		}
+		
 		String result = "";
 
 		TimeZone zone = TimeZone.getTimeZone(timezone);
@@ -610,12 +716,15 @@ public class SleuthkitJNI {
 		}
 		return result;
 	}
-	
+
 	/**
-	 * Get size of a device (physical, logical device, image) pointed to by devPath
+	 * Get size of a device (physical, logical device, image) pointed to by
+	 * devPath
+	 *
 	 * @param devPath device path pointing to the device
 	 * @return size of the device in bytes
-	 * @throws TskCoreException exception thrown if the device size could not be queried
+	 * @throws TskCoreException exception thrown if the device size could not be
+	 * queried
 	 */
 	public static long findDeviceSize(String devPath) throws TskCoreException {
 		return findDeviceSizeNat(devPath);
