@@ -18,6 +18,7 @@
  */
 package org.sleuthkit.datamodel;
 
+import java.util.ArrayList;
 import java.util.List;
 
 /**
@@ -32,7 +33,6 @@ public class Volume extends AbstractContent {
 	private long length; //in sectors
 	private long flags;
 	private String desc;
-	private VolumeSystem parentVs;
 	private long volumeHandle = 0;
 
 	/**
@@ -59,18 +59,14 @@ public class Volume extends AbstractContent {
 		}
 	}
 
-	/**
-	 * set the parent volume system. called by the parent on creation
-	 *
-	 * @param parent parent volume system
-	 */
-	protected void setParent(VolumeSystem parent) {
-		parentVs = parent;
-	}
-
 	@Override
 	public int read(byte[] buf, long offset, long len) throws TskCoreException {
 		synchronized (this) {
+			Content myParent = getParent();
+			if (!(myParent instanceof VolumeSystem)) {
+				throw new TskCoreException("This volume's parent should be a VolumeSystem, but it's not.");
+			}
+			VolumeSystem parentVs = (VolumeSystem)myParent;
 			// read from the volume
 			if (volumeHandle == 0) {
 				volumeHandle = SleuthkitJNI.openVsPart(parentVs.getVolumeSystemHandle(), addr);
@@ -85,13 +81,19 @@ public class Volume extends AbstractContent {
 		return length;
 	}
 
-	/**
-	 * get the parent volume system
-	 *
-	 * @return parent volume system object
-	 */
-	public VolumeSystem getParent() {
-		return parentVs;
+	@Override
+	public synchronized String getUniquePath() throws TskCoreException {
+		String uniquePath = "";
+		String name = getName();
+		if (!name.isEmpty()) {
+			uniquePath = "/vol_" + name;
+		}
+		
+		Content myParent = getParent();
+		if (myParent != null) {
+			uniquePath = myParent.getUniquePath() + uniquePath;
+		}
+		return uniquePath;
 	}
 
 	//methods get exact data from database. could be manipulated to get more
@@ -239,4 +241,21 @@ public class Volume extends AbstractContent {
 	public Image getImage() throws TskCoreException {
 		return getParent().getImage();
 	}
+	
+	/**
+	 * @return a list of FileSystem that are direct descendents of this Image.
+	 * @throws TskCoreException 
+	 */
+	public List<FileSystem> getFileSystems() throws TskCoreException {
+		
+		List<Content> children = getChildren();
+		List<FileSystem> fileSystems = new ArrayList<FileSystem>();
+		for (Content child : children) {
+			if (child instanceof FileSystem) {
+				fileSystems.add((FileSystem)child);
+			}
+		}
+		
+		return fileSystems;
+	}
 }
