@@ -18,6 +18,7 @@
  */
 package org.sleuthkit.datamodel;
 
+import java.util.ArrayList;
 import java.util.List;
 
 /**
@@ -25,9 +26,8 @@ import java.util.List;
  */
 public class VolumeSystem extends AbstractContent {
 
-	private long volumeSystemHandle = 0;
+	private volatile long volumeSystemHandle = 0;
 	private long type, imgOffset, blockSize;
-	private Image parent;
 
 	/**
 	 * Constructor most inputs are from the database
@@ -46,15 +46,6 @@ public class VolumeSystem extends AbstractContent {
 		this.blockSize = blockSize;
 	}
 
-	/**
-	 * set the parent image called by parent on creation
-	 *
-	 * @param parent parent image
-	 */
-	protected void setParent(Image parent) {
-		this.parent = parent;
-	}
-
 	@Override
 	public int read(byte[] readBuffer, long offset, long len) throws TskCoreException {
 		synchronized (this) {
@@ -65,15 +56,6 @@ public class VolumeSystem extends AbstractContent {
 		return SleuthkitJNI.readVs(volumeSystemHandle, readBuffer, offset, len);
 	}
 
-	/**
-	 * get the parent image
-	 *
-	 * @return parent image
-	 */
-	public Image getParent() {
-		return parent;
-	}
-
 	@Override
 	public long getSize() {
 		return 0;
@@ -122,9 +104,15 @@ public class VolumeSystem extends AbstractContent {
 	}
 
 	@Override
-	public void finalize() {
-		if (volumeSystemHandle != 0) {
-			SleuthkitJNI.closeVs(volumeSystemHandle);
+	public void finalize() throws Throwable {
+		try {
+			if (volumeSystemHandle != 0) {
+				SleuthkitJNI.closeVs(volumeSystemHandle);
+				volumeSystemHandle = 0;
+			}
+		}
+		finally {
+			super.finalize();
 		}
 	}
 
@@ -152,4 +140,18 @@ public class VolumeSystem extends AbstractContent {
 	public Image getImage() throws TskCoreException {
 		return getParent().getImage();
 	}
+	
+	/**
+	 * @return a list of Volumes that are direct children of this VolumeSystem
+	 * @throws TskCoreException 
+	 */
+	public List<Volume> getVolumes() throws TskCoreException {
+		List<Volume> volumes = new ArrayList<Volume>();
+		for (Content child : getChildren()) {
+			if (child instanceof Volume) {
+				volumes.add((Volume)child);
+			}
+		}
+		return volumes;
+	}
 }
