@@ -18,7 +18,6 @@
 
 // TSK Framework includes
 #include "TskModuleDev.h"
-#include "Services/TskSystemProperties.h"
 
 // Poco includes
 #include "Poco/Path.h"
@@ -59,7 +58,7 @@ extern "C"
      */
     TSK_MODULE_EXPORT const char *version()
     {
-        return "1.0.0";
+        return "1.0.2";
     }
 
     /**
@@ -88,7 +87,7 @@ extern "C"
         try
         {
             // Create an output folder.
-            Poco::Path outputFolderPath(GetSystemProperty(TskSystemProperties::MODULE_OUT_DIR));
+            Poco::Path outputFolderPath = Poco::Path::forDirectory(GetSystemProperty(TskSystemProperties::MODULE_OUT_DIR));
             outputFolderPath.pushDirectory(name());
             Poco::File(outputFolderPath).createDirectory();
 
@@ -139,7 +138,7 @@ extern "C"
         try
         {
             // Delete the output folder if it's empty.
-            Poco::Path outputFolderPath(GetSystemProperty(TskSystemProperties::MODULE_OUT_DIR));
+            Poco::Path outputFolderPath = Poco::Path::forDirectory(GetSystemProperty(TskSystemProperties::MODULE_OUT_DIR));
             outputFolderPath.pushDirectory(name());
             Poco::File outputFolder(outputFolderPath);
             std::vector<Poco::File> filesList;
