@@ -18,11 +18,16 @@
 #define MAX_BUFF_LENGTH 1024
 
 
-#if defined(TSK_WIN32) && defined(TSK_EXPORTS)
+#if defined(TSK_WIN32) 
+#if defined(TSK_EXPORTS)
     #define TSK_FRAMEWORK_API __declspec(dllexport)
 #else
     #define TSK_FRAMEWORK_API __declspec(dllimport)
 #endif
+// non-win32
+#else
+    #define TSK_FRAMEWORK_API 
+#endif
 
 #if defined(_MSC_VER)
 #pragma warning(disable:4251) // ... needs to have dll-interface warning
