@@ -48,6 +48,7 @@ class TskAutoDb:public TskAuto {
     virtual TSK_RETVAL_ENUM processFile(TSK_FS_FILE * fs_file,
         const char *path);
     virtual void createBlockMap(bool flag);
+    const std::string getCurDir();
 
     /**
      * Calculate hash values of files and add them to database.
@@ -90,7 +91,9 @@ class TskAutoDb:public TskAuto {
     int64_t m_curVolId;     ///< Object ID of volume currently being processed
     int64_t m_curFsId;      ///< Object ID of file system currently being processed
     int64_t m_curFileId;    ///< Object ID of file currently being processed
-    int64_t m_curUnallocDirId;
+    int64_t m_curDirId;		///< Object ID of the directory currently being processed
+    int64_t m_curUnallocDirId;	
+    string m_curDirPath;		//< Path of the current directory being processed
     string m_curImgTZone;
     bool m_blkMapFlag;
     bool m_fileHashFlag;
