@@ -3,7 +3,7 @@
  * The Sleuth Kit 
  *
  * Brian Carrier [carrier <at> sleuthkit [dot] org]
- * Copyright (c) 2008 Brian Carrier.  All Rights reserved
+ * Copyright (c) 2008-2011 Brian Carrier.  All Rights reserved
  *
  * This software is distributed under the Common Public License 1.0
  *
@@ -102,9 +102,9 @@ tsk_fs_file_open_meta(TSK_FS_INFO * a_fs,
     TSK_FS_FILE *fs_file;
 
     if ((a_fs == NULL) || (a_fs->tag != TSK_FS_INFO_TAG)) {
-        tsk_errno = TSK_ERR_FS_ARG;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "tsk_fs_file_open_meta: called with NULL or unallocated structures");
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr
+            ("tsk_fs_file_open_meta: called with NULL or unallocated structures");
         return NULL;
     }
 
@@ -155,9 +155,9 @@ tsk_fs_file_open(TSK_FS_INFO * a_fs,
     TSK_FS_NAME *fs_name = NULL;
 
     if ((a_fs == NULL) || (a_fs->tag != TSK_FS_INFO_TAG)) {
-        tsk_errno = TSK_ERR_FS_ARG;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "tsk_fs_file_open: called with NULL or unallocated structures");
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr
+            ("tsk_fs_file_open: called with NULL or unallocated structures");
         return NULL;
     }
 
@@ -173,9 +173,9 @@ tsk_fs_file_open(TSK_FS_INFO * a_fs,
     }
     else if (retval == 1) {
         tsk_fs_name_free(fs_name);
-        tsk_errno = TSK_ERR_FS_ARG;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "tsk_fs_file_open: path not found: %s", a_path);
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr("tsk_fs_file_open: path not found: %s",
+            a_path);
         return NULL;
     }
 
@@ -207,24 +207,23 @@ tsk_fs_file_attr_check(TSK_FS_FILE * a_fs_file, char *a_func)
     // check the FS_INFO, FS_FILE structures
     if ((a_fs_file == NULL) || (a_fs_file->meta == NULL)
         || (a_fs_file->fs_info == NULL)) {
-        tsk_errno = TSK_ERR_FS_ARG;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "%s: called with NULL pointers", a_func);
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr("%s: called with NULL pointers", a_func);
         return 1;
     }
     else if (a_fs_file->meta->tag != TSK_FS_META_TAG) {
-        tsk_errno = TSK_ERR_FS_ARG;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "%s: called with unallocated structures", a_func);
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr("%s: called with unallocated structures",
+            a_func);
         return 1;
     }
     fs = a_fs_file->fs_info;
 
     // If the attributes haven't been loaded, then load them.
     if (a_fs_file->meta->attr_state == TSK_FS_META_ATTR_ERROR) {
-        tsk_errno = TSK_ERR_FS_INODE_COR;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "%s: called for file with corrupt data", a_func);
+        tsk_error_set_errno(TSK_ERR_FS_INODE_COR);
+        tsk_error_set_errstr("%s: called for file with corrupt data",
+            a_func);
         return 1;
     }
     else if ((a_fs_file->meta->attr_state != TSK_FS_META_ATTR_STUDIED)
@@ -245,8 +244,12 @@ tsk_fs_file_attr_check(TSK_FS_FILE * a_fs_file, char *a_func)
 int
 tsk_fs_file_attr_getsize(TSK_FS_FILE * a_fs_file)
 {
-    if (tsk_fs_file_attr_check(a_fs_file, "tsk_fs_file_attr_getsize"))
+    if (tsk_fs_file_attr_check(a_fs_file, "tsk_fs_file_attr_getsize")) {
+        // @@@ Not sure if we should be ignoring this error or not...
+        // Just added the reset because we were returning 0 with error codes set
+        tsk_error_reset();
         return 0;
+    }
 
     return tsk_fs_attrlist_get_len(a_fs_file->meta->attr);
 }
@@ -308,6 +311,35 @@ tsk_fs_file_attr_get_type(TSK_FS_FILE * a_fs_file,
         return tsk_fs_attrlist_get(a_fs_file->meta->attr, a_type);
 }
 
+/** \ingroup fslib
+* Return a specific attribute by its ID for the file.  
+* @param a_fs_file File to get data from
+* @param a_id Id of attribute to load 
+* @returns NULL on error
+*/
+const TSK_FS_ATTR *
+tsk_fs_file_attr_get_id(TSK_FS_FILE * a_fs_file, uint16_t a_id)
+{
+    int i, size;
+    if (tsk_fs_file_attr_check(a_fs_file, "tsk_fs_file_attr_get_type"))
+        return NULL;
+
+    size = tsk_fs_file_attr_getsize(a_fs_file);
+    for (i = 0; i < size; i++) {
+        const TSK_FS_ATTR *fs_attr =
+            tsk_fs_file_attr_get_idx(a_fs_file, i);
+        if (fs_attr == NULL)
+            return NULL;
+
+        if (fs_attr->id == a_id)
+            return fs_attr;
+    }
+    tsk_error_set_errno(TSK_ERR_FS_ATTR_NOTFOUND);
+    tsk_error_set_errstr
+        ("tsk_fs_attr_get_id: Attribute ID %d not found", a_id);
+    return NULL;
+}
+
 
 /**
 * \ingroup fslib
@@ -333,7 +365,6 @@ tsk_fs_file_walk_type(TSK_FS_FILE * a_fs_file,
     void *a_ptr)
 {
     const TSK_FS_ATTR *fs_attr;
-    TSK_FS_INFO *fs;
 
     // clean up any error messages that are lying around
     tsk_error_reset();
@@ -341,19 +372,18 @@ tsk_fs_file_walk_type(TSK_FS_FILE * a_fs_file,
     // check the FS_INFO, FS_FILE structures
     if ((a_fs_file == NULL) || (a_fs_file->meta == NULL)
         || (a_fs_file->fs_info == NULL)) {
-        tsk_errno = TSK_ERR_FS_ARG;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "tsk_fs_file_walk: called with NULL pointers");
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr
+            ("tsk_fs_file_walk: called with NULL pointers");
         return 1;
     }
     else if ((a_fs_file->fs_info->tag != TSK_FS_INFO_TAG)
         || (a_fs_file->meta->tag != TSK_FS_META_TAG)) {
-        tsk_errno = TSK_ERR_FS_ARG;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "tsk_fs_file_walk: called with unallocated structures");
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr
+            ("tsk_fs_file_walk: called with unallocated structures");
         return 1;
     }
-    fs = a_fs_file->fs_info;
 
     if (tsk_verbose)
         tsk_fprintf(stderr,
@@ -389,7 +419,6 @@ tsk_fs_file_walk(TSK_FS_FILE * a_fs_file,
     TSK_FS_FILE_WALK_CB a_action, void *a_ptr)
 {
     const TSK_FS_ATTR *fs_attr;
-    TSK_FS_INFO *fs;
 
     // clean up any error messages that are lying around
     tsk_error_reset();
@@ -397,19 +426,18 @@ tsk_fs_file_walk(TSK_FS_FILE * a_fs_file,
     // check the FS_INFO, FS_FILE structures
     if ((a_fs_file == NULL) || (a_fs_file->meta == NULL)
         || (a_fs_file->fs_info == NULL)) {
-        tsk_errno = TSK_ERR_FS_ARG;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "tsk_fs_file_walk: called with NULL pointers");
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr
+            ("tsk_fs_file_walk: called with NULL pointers");
         return 1;
     }
     else if ((a_fs_file->fs_info->tag != TSK_FS_INFO_TAG)
         || (a_fs_file->meta->tag != TSK_FS_META_TAG)) {
-        tsk_errno = TSK_ERR_FS_ARG;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "tsk_fs_file_walk: called with unallocated structures");
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr
+            ("tsk_fs_file_walk: called with unallocated structures");
         return 1;
     }
-    fs = a_fs_file->fs_info;
 
     if (tsk_verbose)
         tsk_fprintf(stderr,
@@ -443,7 +471,6 @@ tsk_fs_file_read_type(TSK_FS_FILE * a_fs_file,
     TSK_FS_ATTR_TYPE_ENUM a_type, uint16_t a_id, TSK_OFF_T a_offset,
     char *a_buf, size_t a_len, TSK_FS_FILE_READ_FLAG_ENUM a_flags)
 {
-    TSK_FS_INFO *fs;
     const TSK_FS_ATTR *fs_attr;
 
     // clean up any error messages that are lying around
@@ -452,19 +479,18 @@ tsk_fs_file_read_type(TSK_FS_FILE * a_fs_file,
     // check the FS_INFO, FS_FILE structures
     if ((a_fs_file == NULL) || (a_fs_file->meta == NULL)
         || (a_fs_file->fs_info == NULL)) {
-        tsk_errno = TSK_ERR_FS_ARG;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "tsk_fs_file_read: called with NULL pointers");
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr
+            ("tsk_fs_file_read: called with NULL pointers");
         return -1;
     }
     else if ((a_fs_file->fs_info->tag != TSK_FS_INFO_TAG)
         || (a_fs_file->meta->tag != TSK_FS_META_TAG)) {
-        tsk_errno = TSK_ERR_FS_ARG;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "tsk_fs_file_read: called with unallocated structures");
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr
+            ("tsk_fs_file_read: called with unallocated structures");
         return -1;
     }
-    fs = a_fs_file->fs_info;
 
     if ((fs_attr =
             tsk_fs_file_attr_get_type(a_fs_file, a_type, a_id,
@@ -496,9 +522,8 @@ tsk_fs_file_read(TSK_FS_FILE * a_fs_file,
     const TSK_FS_ATTR *fs_attr;
 
     if ((a_fs_file == NULL) || (a_fs_file->fs_info == NULL)) {
-        tsk_errno = TSK_ERR_FS_ARG;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "tsk_fs_file_read: fs_info is NULL");
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr("tsk_fs_file_read: fs_info is NULL");
         return -1;
     }
 
@@ -521,9 +546,8 @@ tsk_fs_file_get_owner_sid(TSK_FS_FILE * a_fs_file, char **sid_str)
 {
     if ((a_fs_file == NULL) || (a_fs_file->fs_info == NULL)
         || (a_fs_file->meta == NULL) || (sid_str == NULL)) {
-        tsk_errno = TSK_ERR_FS_ARG;
-        snprintf(tsk_errstr, TSK_ERRSTR_L,
-            "tsk_fs_file_get_owner_sid: fs_info is NULL");
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr("tsk_fs_file_get_owner_sid: fs_info is NULL");
         return 1;
     }
 
@@ -531,8 +555,8 @@ tsk_fs_file_get_owner_sid(TSK_FS_FILE * a_fs_file, char **sid_str)
     // This function will only work on NTFS filesystems. 
     if (!a_fs_file->fs_info->fread_owner_sid) {
         tsk_error_reset();
-        tsk_errno = TSK_ERR_FS_UNSUPFUNC;
-        snprintf(tsk_errstr, TSK_ERRSTR_L, "Unsupported function");
+        tsk_error_set_errno(TSK_ERR_FS_UNSUPFUNC);
+        tsk_error_set_errstr("Unsupported function");
         return 1;
     }
 
